#!/usr/bin/python
# -*- coding: utf-8 -*-
"""
U2IF.py
uGao 汎用2次元プロッタ I/F
"""
from __future__ import print_function
import time
import os
import logging
import Manyo
from uGao.uGaoUtil import IFEvtProp, PlotException, MASKVALUE
from uGao.u2dplot import D2Frame, PYSIDEVER
from uGao.u2dplotBase import DataConverter
import math
import Manyo.MLF as mm


import numpy as np

#######################################
#  定数定義
#######################################
MOUSE_UP = 1
REGION_CHANGE = 2
PLOTTER_CLOSED = 3

REGION_RECTANGLE = 0
REGION_LINE = 1
REGION_POINT = 2
REGION_CIRCLE = 3
REGION_RING = 4
REGION_SECTOR = 5
REGION_RING_SECTOR = 6

#######################################
def format_int_range(range0, range1):
    """強度積算範囲設定処理

    引数のどちらかがNoneの時は全範囲になるようにNoneにする。

    Parameters:
        range0 (float or None): 積算範囲始値
        range1 (float or None): 積算範囲終値
    """
    if (range0 is None) or (range1 is None):
        return None
    # 浮動小数点に変換
    try:
        rg0 = float(range0)
        rg1 = float(range1)
    except:
        raise PlotException('Common', 'C027', ('range',))

    if rg1 >= rg0:
        return [rg0, rg1]
    else:
        return [rg1, rg0]

#######################################
#  MousePrms
#######################################


class MousePrms(object):
    """
     マウスパラメータクラス
    """
    #########################################

    def __init__(self, x0, y0, x1=None, y1=None):
        """
        コンストラクタ
        @param  無し
        @retval 無し
        """
        self.X0 = x0
        self.Y0 = y0
        self.X1 = x1
        self.Y1 = y1

#######################################
#  U2IF
#######################################


class U2IF(object):
    """
    uGao 汎用2次元プロッタ I/F クラス
    """

    #########################################
    def __init__(self, parent=None, data=None, order=1, title=None):
        """コンストラクタ

        Parameters:
            parent (QWidget or None):親ウィンドウ。トップレベルウィンドウの場合はNone。
            data (ECM, ECA,or list(np.array, np.array,np.array) ): 表示対象のデータ
            order (int): プロッタ番号(タイトルバーに順番を表示)
            fTitle(str): フレームタイトル
        """
        self.order = order
        # プロパティ管理クラスのインスタンスを取得
        self.ifi = IFEvtProp(order)
        self.inhibit = False
        self.regionEnable = True

        # 初期化
        self.keys = (None, None, None)
        self.intRange = None
        self.parent = parent
        self.order = order
        self.title = title
        self.indices_sort = None
        self.dc = None  # DataConverterインスタンス

        # イベントハンドラ関数
        self.MouseMove = None
        self.ChangeRegionFunc = None
        self.PlotClose = None

        # イベントのリスナ登録
        self.ifi.AddListner(
            'mouse_up', self._OnNotifyMouse)              # マウス情報
        self.ifi.AddListner(
            'u2dclosed', self._OnNotifyPlotClose)         # プロッタクローズ
        self.ifi.AddListner(
            'add_region', self._OnNotifyChangeRegion)     # 領域追加
        self.ifi.AddListner(
            'change_region', self._OnNotifyChangeRegion)  # 領域変更
        self.ifi.AddListner(
            'del_region', self._OnNotifyChangeRegion)     # 領域削除
        self.ifi.AddListner('close_u2dplot', self._OnNotifyClose2dplot)

        self.plot = None

        if data is not None:
            # デフォルト条件でデータを表示
            self.SetData(data)

    #########################################
    def ShowPlot(self, data):
        """プロッタ表示(CUI 専用)

        Parameters:
            data (ECM, ECA,or list(np.array, np.array,np.array) ): 表示対象のデータ
        """
        ndata = DataConverter().ConvertData(data, self.keys, self.intRange)

        if PYSIDEVER == 2:
            # Hi-resolution Display for windows
            if hasattr(QtCore.Qt, 'AA_EnableHighDpiScaling'):
                QtWidgets.QApplication.setAttribute(
                    QtCore.Qt.AA_EnableHighDpiScaling, True)
        app = QtWidgets.QApplication([])
        # Set Default Font Size to (default 14)
        deffont = app.font()
        if "UTSUSEMI_DEFAULT_FONTSIZE" in os.environ:
            deffontsize = int(os.environ["UTSUSEMI_DEFAULT_FONTSIZE"])
            deffont.setPointSize(deffontsize)
        else:
            deffont.setPointSize(10)
        app.setFont(deffont)
        main_window = D2Frame(None, ndata)
        main_window.setWindowTitle("Plot window")
        main_window.show()
        if PYSIDEVER == 6:
            app.exec()
        else:
            app.exec_()

    #########################################
    def Bind(self, btype, func):
        """
        イベントハンドラの設定
        @param  btype(int) イベントタイプ
        @param  func  イベント発生時に実行する関数
        @retval 無し
        """
        if btype == MOUSE_UP:
            self.MouseMove = func
        elif btype == REGION_CHANGE:
            self.ChangeRegionFunc = func
        elif btype == PLOTTER_CLOSED:
            self.PlotClose = func

    #########################################
    def SetKeys(self, xkey, ykey, intkey=None, rkey=None):
        """キー文字列設定処理

        Parameters:
            xkey (str or None): X Key
            ykey (str or None): Y Key
            intkey (str or None): Int Key
            rkey (str or None): Range Key
        """
        if xkey is not None and not isinstance(xkey, str):
            raise PlotException('Common', 'C025', ('xkey',))
        if ykey is not None and not isinstance(ykey, str):
            raise PlotException('Common', 'C025', ('ykey',))
        if intkey is not None and not isinstance(intkey, str):
            raise PlotException('Common', 'C025', ('intkey',))
        if rkey is not None and not isinstance(rkey, str):
            raise PlotException('Common', 'C025', ('rkey',))

        self.keys = (xkey, ykey, intkey, rkey)

    #########################################
    def SetIntRange(self, range0, range1):
        """強度積算範囲設定処理

        self.intRangeに積算範囲を設定する。
        引数のどちらかがNoneの時は全範囲になるようにself.intRangeをNoneにする。

        Parameters:
            range0 (float or None): 積算範囲始値
            range1 (float or None): 積算範囲終値
        """
        self.intRange = format_int_range(range0, range1)

    #########################################
    def SetData(self, data):
        """
        データ設定処理
        @param  data (ECM, ECA,or list(np.array, np.array,np.array) ) 表示対象のデータ
        @retval 無し
        """
        if isinstance(data, Manyo.ElementContainerMatrix) or isinstance(data, Manyo.ElementContainerArray):
            self.dc = DataConverter()
            ndata = self.dc.ConvertData(data, self.keys, self.intRange)
            self.indices_sort = self.dc.PutLastSortIndices()
            # del dc [20170424, TI] TODO: 問題なければ削除
        else:
            ndata = data

        if self.plot is not None:
            # データ変更メッセージ送信
            self.ifi.NotifyEvent(self, 'change_data', ndata)
        else:
            # プロッタクローズメッセージのリスナー登録
            self.ifi.AddListner('close_plot', self._OnNotifyPlotClose)
            # データを表示
            self.plot = D2Frame(self.parent, ndata, self.order, self.title)
            self.plot.setWindowTitle("Plot window")
            self.plot.ifi.DelListner(self.plot.listner_index_slice)
            self.plot.ifi.AddListner(
                'left_mouse_click_cb', self.left_mouse_click_cb)
            self.plot.SetInhibitClose(self.inhibit)
            self.plot.RegionEnable(self.regionEnable)
            self.plot.show()

    #########################################
    def InhibitPlotClose(self, flag):
        """
        プロッタクローズ禁止の設定
        @param  flag (bool) True:禁止 or False: 解除
        @retval 無し
        """
        if self.plot is not None:
            self.plot.SetInhibitClose(flag)
        else:
            self.inhibit = flag

    #########################################
    def InhibitRegion(self, flag):
        """
        領域ダイアログ禁止の設定
        @param  flag (bool) True:禁止 or False: 解除
        @retval 無し
        """
        if self.plot is not None:
            if flag:
                self.plot.RegionEnable(False)
            else:
                self.plot.RegionEnable(True)
        else:
            self.regionEnable = not flag

    #########################################
    def ReadData(self, filename):
        """
        データをファイルより読み込む
        @param  filename (string) ファイルのパス
        @retval True or False
        """
        if self.plot is None:
            return False
        try:
            dat = self.plot.ReadDatFile(filename)
        except:
            return False
        # データ変更メッセージ送信
        self.ifi.NotifyEvent(self, 'change_data', dat)
        return True

    #########################################
    def SetGroups(self, groups, colors):
        """
        グループとカラーを設定
        @param  groups (string list) グループ名
        @param  colors (string list) グループカラー
        @retval 無し
        """
        if self.plot is None:
            return
        cNames = ["White", "Yellow", "Black",
                  "Blue", "Green", "Red", "Cyan", "Purple"]

        crnames = []
        for i in range(len(groups)):
            # グループ数よりすくなければ
            if i >= len(colors):
                crnames.append("White")
            else:
                # 大文字に変換
                crnames.append(colors[i])

        codes = []
        for color in crnames:
            if color in cNames:
                cindex = cNames.index(color)
            else:
                cindex = 0
            codes.append(cindex)

        self.plot.SetGroupColors(groups, crnames, codes)

    #########################################
    def AddRegion(self, regName, values, groupIndex=0):
        """
        領域追加
        @param  regName (string) 領域名
        @param  values (string list) 領域の値
        @param  groupIndex (int) グループ指定
        @retval 無し
        """
        # 領域追加メッセージ送信
        self.ifi.NotifyEvent(self, 'add_region_from_other',
                             (regName, values, groupIndex))

    #########################################
    def GetRegion(self, index=None):
        """
        領域取得
        @param  index (int) 行インデックス、None のとき全データ
        @retval (regName, values, groupIndex)
        """
        # 領域データ取得
        regionData = self.ifi.GetProperty('region_data')
        # インデックスの指定が無いときは、全データ
        if index is None:
            return regionData

        # 指定されたインデックスが領域数を越えていれば
        if index >= len(regionData):
            return None
        return regionData[index]

    #########################################
    def ChangeRegion(self, index, regName, values, groupIndex=0):
        """
        領域のパラメータ変更
        @param  index (int) 行インデックス
        @param  regName (string) 領域名
        @param  values (string list) 領域の値
        @param  groupIndex (int) グループ指定
        @retval 無し
        """
        # 領域変更メッセージ送信
        self.ifi.NotifyEvent(self, 'change_region_prms',
                             (index, regName, values, groupIndex))

    #########################################
    def DeleteRegion(self, index):
        """
        領域削除
        @param  index (int) 行インデックス
        @retval 無し
        """
        # 領域削除メッセージ送信
        self.ifi.NotifyEvent(self, 'del_region_from_other', index)

    #########################################
    def SelectRegion(self, index):
        """
        領域選択
        @param  index (int) 行インデックス
        @retval 無し
        """
        # 領域選択メッセージ送信
        self.ifi.NotifyEvent(self, 'change_selected_row', index)

    #########################################
    def SetRegionType(self, regName):
        """
        領域タイプを設定
        @param  regName (string) 領域名
        @retval 無し
        """
        # 領域タイプ変更メッセージ送信
        self.ifi.NotifyEvent(self, 'select_region', regName)

    #########################################
    def SaveAsBin(self, filename):
        """
        データをバイナリファイルに書き込む
        @param  filename (string) ファイルのパス
        @retval True or False
        """
        if self.plot is None:
            return False
        try:
            self.plot.SaveAsBin(filename)
        except:
            return False
        return True

    #########################################
    def SaveAsTxt(self, filename):
        """
        データをテキストファイルに書き込む
        @param  filename (string) ファイルのパス
        @retval True or False
        """
        if self.plot is None:
            return False
        try:
            self.plot.SaveAsTxt(filename)
        except:
            return False
        return True

    #########################################
    def SetTitles(self, title, comment=None):
        """
        タイトルとコメントの設定
        @param  title (string) グラフのタイトル
        @param  comment (string) コメント
        @retval 無し
        """
        if self.plot is None:
            return
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        # 書き換え
        params.title = title
        if comment is not None:
            params.comment = comment
        # パラメータ変更通知
        self.ifi.NotifyEvent(self, 'change_params')

    #########################################
    def GetTitles(self):
        """
        タイトルとコメントの取得
        @param  無し
        @retval タイトルとコメント
        """
        if self.plot is None:
            return ("", "")
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        return (params.title, params.comment)

    #########################################
    def SetTransPosition(self, trans):
        """
        軸の転置指定
        @param  title (string) グラフのタイトル
        @param  comment (string) コメント
        @retval 無し
        """
        if self.plot is None:
            return
        # 引数の型チェック
        if isinstance(trans, bool):
            # パラメータをプロッタ画面より取得
            params = self.ifi.GetProperty('params')
            # 現在の値と異なっていたなら
            if params.transPosition != trans:
                params.transPosition = trans
                # パラメータ変更通知
                self.ifi.NotifyEvent(self, 'change_params')
        else:
            raise PlotException('Common', 'C028', ('Argument',))

    #########################################
    def GetTransPosition(self):
        """
        軸の転置取得
        @param  無し
        @retval タイトルとコメント
        """
        if self.plot is None:
            return False
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        return params.transPosition

    #########################################
    def SetXScale(self, auto, range0, range1):
        """
        Xスケールパラメータ設定
        @param  auto (bool) 範囲自動か
        @param  range0 (float) 範囲の始値
        @param  range1 (float) 範囲の終値
        @retval 無し
        """
        self._SetScale(True, auto, range0, range1)

    #########################################
    def SetYScale(self, auto, range0, range1):
        """
        Yスケールパラメータ設定
        @param  auto (bool) 範囲自動か
        @param  range0 (float) 範囲の始値
        @param  range1 (float) 範囲の終値
        @retval 無し
        """
        self._SetScale(False, auto, range0, range1)

    #########################################
    def _SetScale(self, xx, auto, range0, range1):
        """
        スケールパラメータ設定
        @param  xx (bool) X軸か
        @param  auto (bool) 範囲自動か
        @param  range0 (float) 範囲の始値
        @param  range1 (float) 範囲の終値
        @retval 無し
        """
        if self.plot is None:
            return
        # 引数の型チェック
        if not isinstance(auto, bool):
            raise PlotException('Common', 'C028', ('auto',))
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        # X軸か
        if xx:
            scale = params.xscale
        else:
            scale = params.yscale
        # 自動か
        if auto:
            if scale.autoRange:
                return
            scale.autoRange = True
        else:
            # 数値か
            try:
                rg0 = float(range0)
                rg1 = float(range1)
            except:
                raise PlotException('Common', 'C027', ('Range',))
            if rg0 >= rg1:
                raise PlotException('Common', 'C009', ('range1', 'range0'))
            scale.range = [rg0, rg1]
        # パラメータ変更通知
        self.ifi.NotifyEvent(self, 'change_params')

    #########################################

    def GetXScale(self):
        """
        X軸範囲取得
        @param  無し
        @retval (auto, range0, range1)
        """
        if self.plot is None:
            return
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        scale = params.xscale
        if scale.range is None:
            return (scale.autoRange, 0.0, 1.0)
        return (scale.autoRange, scale.range[0], scale.range[1])

    #########################################
    def GetYScale(self):
        """
        Y軸範囲取得
        @param  無し
        @retval (auto, range0, range1)
        """
        if self.plot is None:
            return
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        scale = params.yscale
        if scale.range is None:
            return (scale.autoRange, 0.0, 1.0)
        return (scale.autoRange, scale.range[0], scale.range[1])

    #########################################
    def SetXTicksFormat(self, auto, ftype=None, precision=None, fontsize=None):
        """
        X軸のチックラベル設定
        @param  auto (bool) 自動か
        @param  ftype (int) 形式 0: Floating Point, 1: Exponential
        @param  precision (int) 精度
        @param  fontsize(int) フォントサイズ
        @retval 無し
        """
        self._SetTicksFormat(True, auto, ftype, precision, fontsize)

    #########################################
    def SetYTicksFormat(self, auto, ftype=None, precision=None, fontsize=None):
        """
        Y軸のチックラベル設定
        @param  auto (bool) 自動か
        @param  ftype (int) 形式 0: Floating Point, 1: Exponential
        @param  precision (int) 精度
        @param  fontsize(int) フォントサイズ
        @retval 無し
        """
        self._SetTicksFormat(False, auto, ftype, precision, fontsize)

    #########################################
    def _SetTicksFormat(self, xx, auto, ftype=None, precision=None, fontsize=None):
        """
        チックラベル設定
        @param  xx (bool) X軸か
        @param  auto (bool) 自動か
        @param  ftype (int) 形式 0: Floating Point, 1: Exponential
        @param  precision (int) 精度
        @param  fontsize(int) フォントサイズ
        @retval 無し
        """
        if self.plot is None:
            return
        # 引数の型チェック
        if not isinstance(auto, bool):
            raise PlotException('Common', 'C028', ('Auto',))
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        # X軸か
        if xx:
            scale = params.xscale
        else:
            scale = params.yscale
        # 自動か
        if auto:
            if scale.autoTick:
                return
            scale.autoTick = True
        else:
            # 表示形式が指定されているか
            if ftype is not None:
                if not isinstance(ftype, int):
                    raise PlotException('Common', 'C026', ('ftype',))
                if ftype < 0 or ftype > 1:
                    raise PlotException('Common', 'C008', ('ftype', '0', '1'))
                scale.format = ftype
            # 精度が指定されているか
            if precision is not None:
                if not isinstance(precision, int):
                    raise PlotException('Common', 'C026', ('precision',))
                if precision < 0 or precision > 5:
                    raise PlotException(
                        'Common', 'C008', ('precision', '0', '5'))
                scale.precision = precision
            # フォントサイズが指定されているか
            if fontsize is not None:
                if not isinstance(fontsize, int):
                    raise PlotException('Common', 'C026', ('fontsize',))
                if fontsize < 6 or fontsize > 12:
                    raise PlotException(
                        'Common', 'C008', ('fontsize', '6', '12'))
                scale.fontSize = fontsize
        # パラメータ変更通知
        self.ifi.NotifyEvent(self, 'change_params')

    #########################################
    def GetXTicksFormat(self):
        """
        X軸のチックラベル取得
        @param  無し
        @retval 無し
        """
        if self.plot is None:
            return
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        scale = params.xscale
        return (scale.autoTick, scale.format, scale.precision, scale.fontSize)

    #########################################
    def GetYTicksFormat(self):
        """
        Y軸のチックラベル取得
        @param  無し
        @retval 無し
        """
        if self.plot is None:
            return
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        scale = params.yscale
        return (scale.autoTick, scale.format, scale.precision, scale.fontSize)

    #########################################
    def SetLabels(self, xlabel, ylabel):
        """
        軸のラベルを指定
        @param  xlabel (string or None) X軸のラベル
        @param  ylabel (string or None) Y軸のラベル
        @retval 無し
        """
        if self.plot is None:
            return
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        if xlabel is not None:
            params.xscale.label = xlabel
        if ylabel is not None:
            params.yscale.label = ylabel
        # パラメータ変更通知
        self.ifi.NotifyEvent(self, 'change_params')

    #########################################
    def GetLabels(self, ):
        """
        軸のラベルを取得
        @param  無し
        @retval (xlabel, ylabel)
        """
        if self.plot is None:
            return ("", "")
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        return (params.xscale.label, params.yscale.label)

    #########################################
    def SetUnits(self, xunit, yunit):
        """
        軸のUnitを指定
        @param  xunit (string or None) X軸のunit
        @param  yunit (string or None) Y軸のunit
        @retval 無し
        """
        if self.plot is None:
            return
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        if params.xscale.label is not None:
            params.xscale.unit = xunit
        if params.yscale.label is not None:
            params.yscale.unit = yunit
        # パラメータ変更通知
        self.ifi.NotifyEvent(self, 'change_params')

    #########################################
    def GetUnits(self, ):
        """
        軸のUnitを取得
        @param  無し
        @retval (xunit, yunit)
        """
        if self.plot is None:
            return ("", "")
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        return (params.xscale.unit, params.yscale.unit)

    #########################################
    def SetHGrid(self, grid, color=None, interval=None):
        """
        水平グリッドの指定
        @param  grid (string) グラフのタイトル
        @param  color (int) 0:White, 1:Yellow 2:Red, 3:Black, 4:Blue, 5:Green, 6:Cyan, 7:Purple
        @param  interval (float) 間隔
        @retval 無し
        """
        if self.plot is None:
            return
        # 引数の型チェック
        if isinstance(grid, bool):
            # パラメータをプロッタ画面より取得
            params = self.ifi.GetProperty('params')
            params.hgrid = grid
            # カラーが指定されていれば
            if color is not None:
                params.gridColor = color
            # 間隔が指定されていれば
            if color is not None:
                params.hgridInterval = interval
            # パラメータ変更通知
            self.ifi.NotifyEvent(self, 'change_params')
        else:
            raise PlotException('Common', 'C028', ('Argument',))

    #########################################
    def GetHGrid(self):
        """
        水平グリッドの取得
        @param  grid (string) グラフのタイトル
        @param  color (int) 0:White, 1:Yellow 2:Red, 3:Black, 4:Blue, 5:Green, 6:Cyan, 7:Purple
        @param  interval (float) 間隔
        @retval 無し
        """
        if self.plot is None:
            return None
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        return (params.hgrid, params.gridColor, params.hgridInterval)

    #########################################
    def SetVGrid(self, grid, color=None, interval=None):
        """
        垂直グリッドの指定
        @param  grid (string) グラフのタイトル
        @param  color (int) 0:White, 1:Yellow 2:Red, 3:Black, 4:Blue, 5:Green, 6:Cyan, 7:Purple
        @param  interval (float) 間隔
        @retval 無し
        """
        if self.plot is None:
            return
        # 引数の型チェック
        if isinstance(grid, bool):
            # パラメータをプロッタ画面より取得
            params = self.ifi.GetProperty('params')
            params.vgrid = grid
            # カラーが指定されていれば
            if color is not None:
                params.gridColor = color
            # 間隔が指定されていれば
            if color is not None:
                params.vgridInterval = interval
            # パラメータ変更通知
            self.ifi.NotifyEvent(self, 'change_params')
        else:
            raise PlotException('Common', 'C028', ('Argument',))

    #########################################
    def GetVGrid(self):
        """
        垂直グリッドの取得
        @param  grid (string) グラフのタイトル
        @param  color (int) 0:White, 1:Yellow 2:Red, 3:Black, 4:Blue, 5:Green, 6:Cyan, 7:Purple
        @param  interval (float) 間隔
        @retval 無し
        """
        if self.plot is None:
            return None
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        return (params.vgrid, params.gridColor, params.vgridInterval)

    #########################################
    def SetColorMap(self, mapNo, auto, log=False, range0=None, range1=None):
        """
        カラーマップの指定
        @param  mapNo (int) カラーマップ指定　0: Default,  1: Red Scale,  2: Blue Scale,  3: Gray Scale
        @param  auto (bool) 自動範囲指定
        @param  log  (bool) ログスケール指定
        @param  range0 (float) 範囲の始値
        @param  range1 (float) 範囲の終値
        @retval 無し
        """
        if self.plot is None:
            return
        # 引数の型チェック
        if not isinstance(mapNo, int):
            raise PlotException('Common', 'C026', ('mapNo',))
        if not isinstance(auto, bool):
            raise PlotException('Common', 'C028', ('auto',))
        if not isinstance(log, bool):
            raise PlotException('Common', 'C028', ('log',))

        # マップの番号範囲
        if mapNo < 0 or mapNo > (len(COLOR_MAPS) - 1):
            raise PlotException('Common', 'C008', ('mapNo', '0', '3'))
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        params.colorMap = mapNo
        params.logScale = log
        # 自動か
        if auto:
            params.autoRange = auto
        else:
            # 数値か
            try:
                rg0 = float(range0)
                rg1 = float(range1)
            except:
                raise PlotException('Common', 'C027', ('Range',))
            if rg0 >= rg1:
                raise PlotException('Common', 'C009', ('range1', 'range0'))
            params.range = [rg0, rg1]
        # パラメータ変更通知
        self.ifi.NotifyEvent(self, 'change_params')

    #########################################
    def GetColorMap(self):
        """
        カラーマップの取得
        @param  無し
        @retval  (mapNo, auto, log, range0, range1)
        """
        if self.plot is None:
            return None
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        return (params.colorMap, params.autoRange, params.logScale, params.range[0], params.range[1])

    #########################################
    def SetSmooth(self, isSmooth=False, windowVal=1, timesVal=1):
        """
        スムージングの指定
        @param isSmooth   スムージングを行うかどうか
        @param windowVal  スムージングのウィンドウ値
        @param timesVal   the number of times
        @retval None
        """
        if self.plot is None:
            return
        # 引数の型チェック
        if not isinstance(isSmooth, bool):
            raise PlotException('Common', 'C028', ('isSmooth',))
        if not isinstance(windowVal, int):
            raise PlotException('Common', 'C027', ('windowVal',))
        if not isinstance(timesVal, int):
            raise PlotException('Common', 'C027', ('timesVal',))
        if windowVal <= 0.0:
            raise PlotException('Common', 'C010', ('windowVal', '1'))
        if timesVal <= 0.0:
            raise PlotException('Common', 'C010', ('timesVal', '1'))
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        params.smoothing = [isSmooth, windowVal, times]
        # パラメータ変更通知
        self.ifi.NotifyEvent(self, 'change_params')

    #########################################
    def GetSmooth(self):
        """
        スムージング設定の取得
        @param None
        @retval (isSmooth,windowVal) : SetSmoothの引数と同じ
        """
        if self.plot is None:
            return None
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        return (params.smoothing[0], params.smoothing[1], params.smoothing[2])

    #########################################
    def SetBankSeparator(self, flag=False):
        """
        Bank Separatorの指定
        @param flag   Showing bank separators or not
        @retval None
        """
        if self.plot is None:
            return
        # 引数の型チェック
        if not isinstance(flag, bool):
            raise PlotException('Common', 'C028', ('isSmooth',))
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        params.bankseparator = flag
        # パラメータ変更通知
        self.ifi.NotifyEvent(self, 'change_params')

    #########################################
    def SetWindowSize(self, width, height):
        """
        #[inamura 181113]
        """
        if self.plot is None:
            return
        # 引数のチェック
        if isinstance(width, int) or isinstance(width, float):
            pass
        else:
            return
        if isinstance(height, int) or isinstance(height, float):
            pass
        else:
            return
        if width <= 0 or height <= 0:
            return
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        params.window_size[0] = int(width)
        params.window_size[1] = int(height)
        # パラメータ変更通知
        self.ifi.NotifyEvent(self, 'change_params')

    #########################################
    def SetSliceMethod(self, isAve=True):
        """
        #[inamura 190226]
        """
        if self.plot is None:
            return
        # 引数のチェック
        if isinstance(isAve, bool):
            pass
        else:
            return
        # パラメータをプロッタ画面より取得
        params = self.ifi.GetProperty('params')
        params.slice_ave_mode = isAve
        # パラメータ変更通知
        self.ifi.NotifyEvent(self, 'change_params')

    #########################################
    def SetDetectMapMode(self, isDetMapMode=True):
        """
        """
        if self.plot is None:
            return
        # 引数のチェック
        if isinstance(isDetMapMode, bool):
            pass
        else:
            return
        params = self.ifi.GetProperty('params')
        params.detectmapmode = isDetMapMode
        # 再描画通知
        self.ifi.NotifyEvent(self, 'change_params')

    #########################################
    def _OnNotifyClose2dplot(self, eventSrc, evtType, dat=None):
        """
        Close u2dplot::D2Frame #[inamura 181001]
        @param eventSrc   イベント発生元インスタンス
        @param  evtType (str) 発生したイベントのタイプ
        @retval 無し
        """
        try:
            self.plot.Close()
        except:
            raise UserWarning("Failed u2dplot::D2Frame::Close")

    #########################################
    def _OnNotifyPlotClose(self, eventSrc, evtType, dat=None):
        """
        プロッタクローズメッセージ受信
        @param eventSrc   イベント発生元インスタンス
        @param  evtType (str) 発生したイベントのタイプ
        @retval 無し
        """
        self.plot = None
        # イベントハンドラが設定されているか
        if self.PlotClose is not None:
            # apply(self.PlotClose, (self.order,))
            self.PlotClose(self.order)

    #########################################
    def _OnNotifyMouse(self, wid, evt, dat):
        """
        マウスアップイベント受信
        @param  wid イベント発生元
        @param  evt イベントデータ
        @param  dat (transPosition, x0,y0,x1,y1)
        @retval 無し
        """
        # イベントハンドラが設定されているか
        if self.MouseMove is None:
            return
        transPosition, x0, y0, x1, y1 = dat
        # 軸の転置が指定されていれば
        if transPosition:
            # データを入れ替え
            tmp = x0
            x0 = y0
            y0 = tmp
            tmp = x1
            x1 = y1
            y1 = tmp

        self.MouseMove(*(MousePrms(x0, y0, x1, y1),))

    #########################################
    def _OnNotifyChangeRegion(self, wid, evt, dat):
        """
        領域追加・変更イベント受信
        @param  wid イベント発生元
        @param  evt イベントデータ
        @param  dat (transPosition, x0,y0,x1,y1)
        @retval 無し
        """
        # イベントハンドラが設定されているか
        if self.ChangeRegionFunc is not None:
            apply(self.ChangeRegionFunc)

    #########################################
    def IsTransposed(self):
        """
        転置であるかを返す

        Returns:
            bool
        """
        params = self.ifi.GetProperty('params')
        return params.transPosition

    #########################################
    def GetBins(self):
        """
        表示中のデータのbinを返す

        Returns:
            Tuple(ndarray, ndarray) xbin, ybin
        """
        return self.plot.data[1][0], self.plot.data[2].T[0]

    #########################################
    def GetQuadMesh(self):
        """
        描画された2次元プロット情報を返す

        Returns:
            matplotlib.collections.QuadMesh
        """
        return self.plot.d2.GetQuadMesh()

    #########################################
    def GetSelectedRegPath(self):
        """
        選択されている領域のpathを返す

        Returns:
            matplotlib.path.Path 選択されている領域のpath
        """
        for diagram in self.plot.d2.regAxes.get_children():
            if diagram.get_gid() == "selected":
                return diagram.get_patch_transform().transform_path(diagram.get_path())
        return None

    #########################################
    def GetSelectedRegInfo(self):
        """
        選択されている領域情報を返す

        Retunrs:
            list 領域情報のリスト　[領域名、カラー、値のリスト、選択否選択のbool]
        """
        for region in self.plot.d2.regInfos:
            if region[3]:
                return region
        return region


#########################################
if __name__ == '__main__':

    '''
    import ana.Reduction.BaseCommands as bc

    eca = bc.LoadDataFromDump( "./files/", "eca.dmp" )
    bc.SaveDataToDump( mat(10), "./", "eca.dmp" )
    app = wx.PySimpleApp()
    u2 = U2IF(None, None)
    u2.SetKeys(u'DETID',None, u'Qx')
     u2.SetIntRange(-0.2,0.0)
    mat = bc.LoadDataFromDump( "./files/", "SAS104212_SM_lam_20140209.dmp" )
    hh = mat(237).PutHeaderPointer()
    hh.OverWrite("MASKED", 1)
    # u2.SetData(mat)
    # app.MainLoop()
    '''

    TestU2IF()



#!/usr/bin/python
# -*- coding: utf-8 -*-
"""
WxApp.py
GUI ローンチャー
wxPython アプリとCUI のインターフェイス
"""
import subprocess
import tempfile
import time
import cPickle as pickle
import os, sys
import wx
import threading, Queue
import socket
from vis.UtilPlot import AcqPath


#######################################
#  WxApp
#######################################  
class WxApp(wx.App):
    """
    wxPython アプリとCUI のインターフェイスクラス
    GUI アプリケーションから起動され、最上位のWxPython 
    アプリケーション及びソケットサーバとして機能する。
    """
    #############################################
    def OnStart(self, portno, closeFlag, func):
        """
        タイマー監視のスタート
        @param  portno     ソケットのポート番号
        @param  closeFlag  親プロセス終了時に自死するかどうかのフラグ
        @param  func       コマンド解析・実行用のコールバック関数
        @retval 無し
        """ 
        self.func = func
        self.closeFlag = closeFlag
        
        # ソケットサーバー準備
        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
        sock.bind(('127.0.0.1', portno))
        # タイムアウトを 15 秒に設定
        sock.settimeout(15.0)
        # 受信準備
        sock.listen(1)
        # クライアントと接続
        try:
            (conn, sa) = sock.accept()
        except socket.error, e:
            print 'Error: %s' % e
            return
        # 受信待ち時停止指定
        conn.setblocking(True)
        
        # スレッド間通信用のキューを準備
        self.datQueue = Queue.Queue()
        self.ansQueue = Queue.Queue()
        
        # サブスレッドの終了フラグを準備
        self.stopFlag = False

        # サブスレッドスタート
        th = threading.Thread(target=self.SocketServer, args=(conn,))
        th.setDaemon(True)
        th.start()

        # 0.3　秒毎のタイマー
        self.timer = wx.Timer(self)
        self.timer.Start(300)
        self.Bind(wx.EVT_TIMER, self.TimerHandler)

    #############################################
    def TimerHandler(self, evt):
        """
        タイマー監視ルーチン
        CUIからのコマンドを受信したらコマンド解析クラスを
        通じてデータを送信
        @param  evt イベント情報
        @retval 無し
        """ 
        # コマンドがあれば
        if self.datQueue.qsize() > 0:
            # キューからコマンドを読み出す
            strCmd = self.datQueue.get()
            # コマンド実行前の時間を保存
            t1 = time.time()
            # GUI アプリから渡されたコマンド解析処理コールバック関数を実行
            ret = apply(self.func, (strCmd,))  

            # コマンド終了後の時間を取得
            t2 = time.time()
            # コマンドの実行に 10秒以上かかった場合は
            # 通信スレッドが既に NACK を送信しているため、ここでは送信しない 
            if t1+10.0 > t2:
                # 応答が特に無ければ正常応答を返信
                if ret == None:
                    ret = "ACK\n"
                # 返信要求をだす
                self.ansQueue.put(ret)

    #####################################################    
    def OnGUIClose(self):
        """
        トップレベルウィンドウクローズイベント対応処理
        @param  無し   
        @retval 無し
        """      
        # タイマー停止 
        self.timer.Stop()
        # サブスレッドの停止フラグを立てる
        self.stopFlag = True

    #############################################        
    def SocketServer(self, sock) :
        """
        ソケットからコマンドを取得し、レスポンスを返す
        (サブスレッドにて実行)
        @param  sock ソケットオブジェクト
        @retval 無し
        """ 
        # 永久ループ(トップレベルのウィンドウクローズ時、またはクライアント終了時に終了)
        while True:
            # アプリケーションが終了したか
            if self.stopFlag:
                # 接続終了
                break
            # コマンドを読み込む
            cmd = self.GetCommand(sock)
            # 接続維持コマンドではないならば
            if not cmd == "keepalive":
                # コマンドをメインスレッドへ送信
                self.datQueue.put(cmd)
                # メインスレッドからの返信待ち(タイムアウト10秒)
                try:
                    # キューから応答を読み出す
                    answer = self.ansQueue.get(timeout = 10.0)
                except:
                    # タイムアウトでコマンド実行エラーを返信
                    answer = "NACK\n"
                try:
                    # CUIへ応答を返信
                    sock.send(answer)
                except:
                    # クライアントが接続を終了している
                    break
                
        # 接続終了   
        sock.close()
        # wxPython のメインループを終了させる(Linux では必要)
        wx.Exit()


    #############################################        
    def GetCommand(self, sock) :
        """
        1個のコマンドを取得
        @param  sock ソケットオブジェクト
        @retval 無し
        """         
        # コマンドを受信するまで待っている
        while True:
            cmd = ""
            # コマンドが分割された場合のプロテクト
            # 1個のコマンドが10以上に分割されていればコマンドを破棄
            for i in range(10):
                try:
                    # コマンド読み込み
                    data = sock.recv(1024)
                    # クライアントが終了したか
                    # (Linux Python 2.4　対応: 例外が発生せずに、ブロッキングされなくなるようだ)
                    if data == "":
                        # 親プロセス終了時の終了が指定されているか
                        if self.closeFlag:
                            self.stopFlag = True
                            # アプリケーション終了要求を出す
                            return "close"
                    # 改行コードがあるか
                    if '\n' in data:
                        # 改行コードの前までをコマンドとして取り出す
                        cmd = cmd + data[:data.find('\n')]
                        # コマンドを返す
                        return cmd
                                        
                    # コマンドが未完であれば
                    elif len(data) > 0:
                        # 連結
                        cmd = cmd + data
                        time.sleep(0.1)
                # クライアント終了による例外発生      
                except:
                    # 親プロセス終了時の終了が指定されているか
                    if self.closeFlag:
                        # クライアント終了による、アプリケーション終了
                        self.stopFlag = True
                        return "close"

#######################################
#  CommWx
####################################### 
class CommWx(object) :
    """
    CUI から起動されるCUI-GUI 通信インターフェイスクラス
    指定されたアプリケーションをプロセスとして起動し
    プロセス間通信により、コマンドを送信し
    応答を受信する。
    コマンド・及びレスポンスは'\n'をターミネータ
    とするアスキー文字列である。 
    """
    
    #########################################
    def NewComm(self, portno, args):
        """
        args[0] で指定されたバイソンモジュールを別プロセス
        として起動しソケットにより通信接続する。
        @param  portno ソケット通信用のポート番号
        @param  args   起動モジュール名と引数(文字列)のタプル
        @retval True: 起動と通信接続に成功　　False: 失敗
        """ 

        wxapppath = ""
        # 環境変数PYTHONPATHに指定されたディレクトリを取得
        paths = str( os.environ.get('PYTHONPATH')).split(os.pathsep)
        ##[inamura 100720]-->
        paths_b = []
        for pp in paths:
            paths_b.append( os.path.join( pp,"vis" ) )
        paths = paths+paths_b
        ##<--[inamura 100720]
        # 全PYTHONPATHディレクトリを探索
        for path in paths:
            fpath = os.path.normpath(os.path.join(path,args[0]))
            # ディレクトリに目的ファイルがあるか
            if os.path.isfile(fpath):
                wxapppath = fpath
                break
        # 指定されたモジュールが見つからなかったら
        if wxapppath == "":
            fpath = AcqPath().GetModulePath(args[0])
            if fpath == None:
                print "\nError!!  There is not %s in any directory specified by PYTHONPATH." % args[0]
                return False
                
        # 起動文字列作成
        strPort = "%d" % portno
        cmd = ["python", fpath, strPort]
        # 引数文字列付加       
        for arg in args:
            cmd.append(arg) 

        try:
            # アプリケーションを別プロセスとして起動
            self.plot=subprocess.Popen(cmd)
        except:
            print "\nError!!  Failed to create a new process."
            return False

        # ソケットクライアントの準備
        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        
        # タイムアウトを 13 秒に設定
        sock.settimeout(13.0)
        # 起動待ち
        time.sleep(1.0)
        # プラットフォームが Mac なら
        if sys.platform == "darwin":
            # 起動待ち時間を追加。不具合により、Mac では一度接続に失敗すると
            # リトライによる再接続ができないため
            time.sleep(9.0)
        # 接続(リトライ10回)
        for i in range(10):
            time.sleep(3.0)
            try:
                # ローカルホストのサーバと接続
                r = sock.connect(('127.0.0.1', portno))
            except socket.error, e:
                # タイムアウト 3×10 秒
                if i == 9:
                    print '\nError: %s' % e
                    return False
            # 接続成功    
            else:
                break
            
        # スレッド間のコマンド送受信用のキューを準備
        self.cmdQueue = Queue.Queue()
        self.ansQueue = Queue.Queue()
        # 通信サブスレッドスタート
        thin = threading.Thread(target=self.SocketClient, args=(sock,))
        thin.setDaemon(True)
        thin.start()
        # 新アプリケーション起動・接続が成功
        return True

    #############################################        
    def SocketClient(self, sock) :
        """
        起動したプロセスへのコマンド送信と応答の受信
        (サブスレッドにて実行)
        @param  sock　ソケットオブジェクト
        @retval 無し
        """ 
        # 永久ループ
        while True:
            # 起動したアプリケーションが生きているか
            if self.plot.poll()==None:
                # キューからコマンドを読み出す
                try:
                    cmd = self.cmdQueue.get(timeout = 3.0)
                except:
                    try:
                        # 接続維持コマンド送信(3秒毎)
                        sock.send("keepalive\n")
                    except socket.error, e:
                        break
                else:
                    ans = "NACK"
                    try:
                        # アプリケーションへコマンド送信
                        sock.send(cmd)
                        # 返信読み込み
                        ans = self.GetRespons(sock)
                    except socket.error, e:
                        print '\n%s' % e
                    
                    # 応答キューに書き込み
                    self.ansQueue.put(ans)
                    
            # 起動したアプリケーションが終了したなら
            else:
                # アプリケーション終了による通信スレッド終了
                break
        try:
            # アプリケーション終了メッセージ    
            print "\nApplication End"
            # ソケットをクローズ  
            sock.close()
        except:
            # Python インタープリタ終了時に例外が発生することがあるため
            pass

    #############################################        
    def GetRespons(self, sock) :
        """
        レスポンスを取得
        @param  sock ソケットオブジェクト
        @retval 無し
        """         
        # レスポンスを受信するまで待っている
        while True:
            ans = ""
            # レスポンスが分割された場合のプロテクト
            for i in range(10):
                # レスポンス読み込み 
                try:
                    data = sock.recv(1024)
                except:
                    return "NACK"
                # 改行コードがあるか
                if '\n' in data:
                    # 改行コードの前までをコマンドとして取り出す
                    ans = ans + data[:data.find('\n')]
                    # 受信したレスポンスを返す
                    return ans
                                        
                # レスポンスが未完であれば
                elif len(data) > 0:
                    # 連結
                    ans = ans + data
                    time.sleep(0.1)
   

    #########################################         
    def IsAliveComm(self):
        """
        アプリケーションの生存確認
        @param  無し
        @retval True: 生存、False: 消滅
        """ 
        # アプリケーションが生きているか
        if self.plot.poll()==None:
            return True
        # 既に閉じられている
        else:
            return False
        
    #########################################         
    def PutCommand(self, strCmd):
        """
        コマンドを通信スレッドへ送信(キューに書き込む)
        (本関数はメインスレッドで実行)
        @param  strCmd 通信コマンド文字列
        @retval コマンドに対する応答
        """ 
        # アプリケーションが生きているか
        if self.plot.poll()==None:
            # 送信キューへ書き込み
            self.cmdQueue.put(strCmd)
            
            # アプリケーションからの返信待ち(タイムアウト15秒)
            try:
                # キューからコマンドを読み出す
                answer = self.ansQueue.get(timeout = 15.0)
            except:
                # 15秒以内に応答が無かったので    
                answer = "NACK"
            return answer
        # 既に閉じられている   
        else:
            # 終了エラー    
            print "The aplication has been already closed." 
          





#!/bin/env python
# -*- coding: utf-8 -*-
#
# Usage: runlist.py initial_run_no [final_run_no]
#    initial_run_no, final_run_no:
#       range of run numbers to be listed.
#    -np: does not show proton counts

# [inamura 200907] Update to be executable on both Python2 and Python3, to enable 7T magnet

from __future__ import print_function
import sys
import os
import glob
import Manyo as mm
import Manyo.MLF as mmlf
import Manyo.Utsusemi as mu
import utsusemi.ana.Reduction.BaseCommands as BC

ver = float(sys.version_info[0]) + float(sys.version_info[1]) * 0.1
if ver < 2.5:
    from elementtree.ElementTree import ElementTree
else:
    from xml.etree.ElementTree import ElementTree

MAKERUNLIST_KEY_PROTONS = "protons"
MAKERUNLIST_KEY_KICKERS = "kickers"
MAKERUNLIST_KEY_GONIO = "gonio"
#########################################


def usage(argv):
    print("------------------------------------------------------------------------")
    print("Usage  %s [option] <initial_run_no> [<final_run_no>]" % (argv[0]))
    print("       initial_run_no, final_run_no : range of run numbers to be listed.")
    print("------------------------------------------------------------------------")
    print("Option")
    print("       -np          : does not show proton counts")
    print("       -f filename  : saves the list as a text file named filename")
    print("       -r directory : top directory of IROHA2 log folders, like /opt/mlfsoft/data.")
    print("------------------------------------------------------------------------")
    sys.exit(0)

#########################################
# copied from GetMeasBC.py by Y. Inamura


def GetMeasBC(runNo, flag_proton, offset_sec=0.0, isCT8Neutron=False):
    TT = mu.T0TreatToolsNeunet()
    # root_data_dir = os.environ["UTSUSEMI_DATA_DIR"]
    # inst_code = os.environ["UTSUSEMI_SYS_NAME"]
    inst_code = mu.UtsusemiEnvGetInstCode()
    root_data_dir = mu.UtsusemiEnvGetDataDir()
    st_RUNNO = "%3s%06d" % (inst_code, runNo)
    list_DATA_folder = os.listdir(root_data_dir)
    target_dir = ""

    for a_DATA_folder in list_DATA_folder:
        if a_DATA_folder.find(inst_code) < 0:
            continue

        a_path = os.path.join(root_data_dir, a_DATA_folder)
        if os.path.isdir(a_path):
            list_DATA = os.listdir(a_path)
            for a_data_dir in list_DATA:
                if a_data_dir.find(st_RUNNO) == 0:
                    target_dir = os.path.join(a_path, a_data_dir)
                    break
        if target_dir != "":
            break

    if target_dir == "":
        err_message = "There is no data;{}".format(st_RUNNO)
        raise UserWarning(err_message)
    edb_list = glob.glob(target_dir + "/*.edb")
    edb_list.sort()
    first_file = edb_list[0]
    edb_list = glob.glob(target_dir + "/%s*.edb" % (first_file[-24:-7]))
    edb_list.sort()

    if len(edb_list) == 0:
        err_message = "There is no edb data;{}".format(st_RUNNO)
        raise UserWarning(err_message)
    target_edb = mm.MakeStringVector()
    for a_file in edb_list:
        target_edb.append(a_file)

    TT.readOrgEvent(target_edb)
    mpv2 = TT.putMeasPeriodFromT0()

    mpv = mm.MakeDoubleVector()
    for i in range(7):
        mpv.append(mpv2[i])
    for i in range(7):
        mpv.append(mpv2[mpv2.size() - 1 - 6 + i])
    if mpv.size() != 14:
        err_message = "False to get measuring period from Event Data"
        raise UserWarning(err_message)
    start_date = "%04d/%02d/%02d" % (int(mpv[0]), int(mpv[1]), int(mpv[2]))
    start_time = "%02d:%02d:%02d" % (int(mpv[3]), int(mpv[4]), int(mpv[5]))
    end_date = "%04d/%02d/%02d" % (int(mpv[7]), int(mpv[8]), int(mpv[9]))
    end_time = "%02d:%02d:%02d" % (int(mpv[10]), int(mpv[11]), int(mpv[12]))

    proton = "     ---  "
    kicker = "     ---  "
    if flag_proton == 0:  # does not show proton counts
        pass
    else:  # show proton counts
        #        print "NormByBeamCurrent(runNo=%d)" % runNo
        #        print "     begin date and time = ",start_date," ",start_time
        #        print "       end date and time = ",end_date," ",end_time
        if flag_proton == 1 or flag_proton == 3:
            bc, ratio, org_bc = BC.getBeamCurrentWithCorrectRatio(
                start_date, start_time, end_date, end_time, offset_sec, isCT8Neutron)
            proton = "%14.4f" % (bc)
        if flag_proton == 2 or flag_proton == 3 or flag_proton == 4:
            kk = TT.PutT0Index()
            kicker = "%10d" % (int(kk.size()))
        if flag_proton == 4:
            bc, ratio, org_bc = BC.getBeamCurrentWithCorrectRatio(
                start_date, start_time, end_date, end_time, offset_sec, isCT8Neutron)
            proton = "%14.4f %14.4f %10g" % (bc, org_bc, ratio)
    del TT
    return (runNo, start_date, start_time, end_date, end_time, proton, kicker)

#########################################


def MakeRunList(argv):

    Output = []  # list where the output is stored

    # header of the output
    # Output.append("  run#           start                 end              protons     T_A    T_B     gonio")

    argc = len(argv)  # number of argument
    if (argc < 2):
        usage(argv)  # show help and exit

    flag_proton = 1
    offset_sec = 0.0
    # analysis arguments
    output_name = ""
    data_folder = "/opt/mlfsoft/data"
    devname_temp = "LS340"
    devname_gonio = "Gonio-1"

    is7TmagnetTemp = False
    is7TmagnetGonio = False
    isLS336Temp = False
    isHe3TLGonio = False
    isHe3TLTemp = False
    isCRY3HETemp = False
    paramname_7Tmagnet_dict = {"EA": "SIMSTEP_stsAngle",
                               "SA": "SIMSTEP_prmAngle"}  # Encoder Angle and Set Angle
    paramname_7Tmagnet_gonio = "SIMSTEP_stsAngle"

    init_no = -1
    fin_no = -1
    ind = 1
    isCT8Neutron = False
    while(True):
        if argv[ind] == "-np":
            flag_proton = 0
        elif argv[ind] == "-p":
            flag_proton = 1
        elif argv[ind] == "-k":
            flag_proton = 2
        elif argv[ind] == "-pk" or argv[ind] == "-kp":
            flag_proton = 3
        elif argv[ind] == "-a" or argv[ind] == "-all":
            flag_proton = 4
        elif argv[ind] == "-f":
            if ind == (len(argv) - 1):
                usage(argv)
            ind += 1
            output_name = argv[ind]
        elif argv[ind] == "-r":
            if ind == (len(argv) - 1):
                usage(argv)
            ind += 1
            data_folder = argv[ind]
        elif argv[ind] == "-os":
            if ind == (len(argv) - 1):
                usage(argv)
            ind += 1
            offset_sec = float(argv[ind])
        elif argv[ind] == "-T":
            if ind == (len(argv) - 1):
                usage(argv)
            ind += 1
            devname_temp = argv[ind]
            # if dev is 7T magnet
            if devname_temp.upper().find("7TMAG") >= 0:
                is7TmagnetTemp = True
            elif devname_temp.find("336") >= 0:
                isLS336Temp = True
            elif devname_temp.upper().find("HE3TL") >= 0:
                isHe3TLTemp = True
            elif devname_temp.upper().find("CRY3HE") >= 0:
                isCRY3HETemp = True
            else:
                pass

        elif argv[ind] == "-G":
            if ind == (len(argv) - 1):
                usage(argv)
            ind += 1
            devname_gonio = argv[ind]
            # if dev is 7T magnet
            if devname_gonio.upper().find("7TMAG") >= 0:
                is7TmagnetGonio = True
                v = devname_gonio.split("-")
                if len(v) == 2:
                    devname_gonio = v[0]
                    if v[1] in ["EA", "SA"]:
                        paramname_7Tmagnet_gonio = paramname_7Tmagnet_dict[v[1]]
                    else:
                        raise UserWarning(
                            "MakeRunList 7Tmagnet Gonio argument is invalid : -EA(Encoder Angle) or -SA(Set Angle)")
                elif len(v) == 1:
                    devname_gonio = v[0]
                else:
                    raise UserWarning(
                        "MakeRunList 7Tmagnet Gonio argument is invalid")
            elif devname_gonio.upper().find("HE3TL") >= 0:
                isHe3TLGonio = True
            else:
                pass

        elif argv[ind] == "-CT8n":  # if use CT8Neutron
            isCT8Neutron = True
        else:
            if init_no < 0:
                init_no = int(argv[ind])
            else:
                fin_no = int(argv[ind])

        ind += 1
        if ind >= len(argv):
            break

    if init_no < 0:
        usage(argv)
    if fin_no < 0:
        fin_no = init_no

    run_no = init_no  # run number

    if isCT8Neutron:
        proton_source = "CT8n"
    else:
        proton_source = " CT9"

    if flag_proton == 0 or flag_proton == 1:
        Output.append("  run#           start                 end              %s(%s)      T_A    T_B      %s"
                      % (MAKERUNLIST_KEY_PROTONS, proton_source, MAKERUNLIST_KEY_GONIO))
    elif flag_proton == 2:
        Output.append("  run#           start                 end                %s      T_A    T_B      %s"
                      % (MAKERUNLIST_KEY_KICKERS, MAKERUNLIST_KEY_GONIO))
    elif flag_proton == 3:
        Output.append("  run#           start                 end                %s    %s(%s)      T_A    T_B    %s"
                      % (MAKERUNLIST_KEY_KICKERS, MAKERUNLIST_KEY_PROTONS, proton_source, MAKERUNLIST_KEY_GONIO))
    elif flag_proton == 4:
        Output.append("  run#           start                 end           %s        %s           %4s      ratio      T_A     T_B     %s"
                      % (MAKERUNLIST_KEY_KICKERS, MAKERUNLIST_KEY_PROTONS, proton_source, MAKERUNLIST_KEY_GONIO))

    sys_name = mu.UtsusemiEnvGetInstCode()
    while(True):
        # xml file where the experimental condition is stored
        run_number_wild = "%s%06d_*" % (sys_name, run_no)
        # Search /data/SIK, /data/SIK00, ..., /data/SIK*
        run_folder_list = glob.glob(os.path.join(data_folder, sys_name + "*"))
        run_folder_list.sort()
        run_folder = ""
        run_number_list = []
        # a_run_folder is /data/SIK, /data/SIK00, /data/SIK01, ...
        for a_run_folder in run_folder_list:
            # find /data/SIK*/SIK000000_YYYYMMDD
            run_number_list.extend(
                glob.glob(os.path.join(a_run_folder, run_number_wild)))
            if len(run_number_list) != 0:
                run_folder = a_run_folder
                # break
        if run_folder == "":
            raise UserWarning("Run folder not found : {}".format(run_folder))

        if len(run_number_list) != 0:
            fullpath = ""
            for a_run_num_path in run_number_list:
                tmppath = os.path.join(
                    a_run_num_path, "params", ("run%06d.xml" % (run_no)))
                if os.path.exists(tmppath):
                    fullpath = tmppath
                    break
            if fullpath == "":
                raise UserWarning("Not found run{:06d}.xml".format(run_no))

            tt = mmlf.BoostXmlParser()
            tt.Load(fullpath)
            # gonio_path="runInfo/paramsList/devParam,name:%s/params/param/th"%(devname_gonio)
            # temp_path="runInfo/paramsList/devParam,name:%s/params/tmpcnt"%(devname_temp)
            runno_path = "runInfo/runNo"
            runno = int(tt.PutContent(runno_path))

            # read temperature
            temp_a = ""
            temp_b = ""
            # if dev is 7T magnet
            if is7TmagnetTemp:
                tempV_path = "runInfo/measRslt/devLog,devName:%s/devStatus/params/param/LS340_stsTempVTI" % (
                    devname_temp)
                tempS_path = "runInfo/measRslt/devLog,devName:%s/devStatus/params/param/LS340_stsTempSample" % (
                    devname_temp)
                if not tt.hasPath(tempV_path):  # if not found the tag of the old version params.xml from 7T magnet IROHA2
                    tempV_path = "runInfo/measRslt/devLog,devName:{}/devStatus/params/param/LS340a_stsTempVTI".format(devname_temp)
                    tempS_path = "runInfo/measRslt/devLog,devName:{}/devStatus/params/param/LS340b_stsTempSample".format(devname_temp)
                    if not tt.hasPath(tempV_path):
                        raise UserWarning("Not found 7TMagnet Temperature tag ({})".format(tempV_path))
                # read temperature VTI
                tempV_cnt = tt.PutContent(tempV_path)
                if tempV_cnt == "":
                    temp_a = "  --- "
                else:
                    temp_a = "%6.2f" % (float(tempV_cnt))

                # read temperature Samplpe
                tempS_cnt = tt.PutContent(tempS_path)
                if tempS_cnt == "":
                    temp_b = "  --- "
                else:
                    temp_b = "%6.2f" % (float(tempS_cnt))

                Output[0] = Output[0].replace("  T_A", "T_VTI")
                Output[0] = Output[0].replace("   T_B", "T_Samp")
            elif isLS336Temp:
                devname_temp_list = devname_temp.split(",")
                temp_path = "runInfo/measRslt/devLog,devName:%s/devStatus/params/param" % (
                    devname_temp_list[0])
                temp_kelvin_dic = {"A": "kelvinA", "B": "kelvinB", "C": "kelvinC", "D": "kelvinD",
                                   "D2": "kelvinD2", "D3": "kelvinD3", "D4": "kelvinD4", "D5": "kelvinD5"}

                temp1 = ""
                temp2 = ""
                if len(devname_temp_list) == 1:
                    temp1 = tt.PutContent(temp_path + "/" + temp_kelvin_dic["A"])
                    temp2 = tt.PutContent(temp_path + "/" + temp_kelvin_dic["B"])
                elif len(devname_temp_list) == 2:
                    if devname_temp_list[1].upper() in temp_kelvin_dic:
                        Output[0] = Output[0].replace(
                            "  T_A", temp_kelvin_dic[devname_temp_list[1].upper()])
                        Output[0] = Output[0].replace("   T_B", "None")
                    else:
                        raise UserWarning(
                            "Given senser {} is invalid".format(devname_temp_list[1]))
                    temp1 = tt.PutContent(
                        temp_path + "/" + temp_kelvin_dic[devname_temp_list[1].upper()])
                    temp2 = ""
                elif len(devname_temp_list) == 3:
                    if (devname_temp_list[1].upper() in temp_kelvin_dic) and (devname_temp_list[2].upper() in temp_kelvin_dic):
                        Output[0] = Output[0].replace(
                            "  T_A", temp_kelvin_dic[devname_temp_list[1].upper()])
                        Output[0] = Output[0].replace(
                            "  T_B", temp_kelvin_dic[devname_temp_list[2].upper()])
                    else:
                        raise UserWarning("Given senser {} or {} is invalid".format(
                            devname_temp_list[1], devname_temp_list[2]))
                    temp1 = tt.PutContent(
                        temp_path + "/" + temp_kelvin_dic[devname_temp_list[1].upper()])
                    temp2 = tt.PutContent(
                        temp_path + "/" + temp_kelvin_dic[devname_temp_list[2].upper()])
                else:
                    raise UserWarning("ERROR for LS336 ")
                if temp1 != "":
                    if float(temp1) < 10.0:
                        temp_a = "{:6.4f}".format(float(temp1))
                    elif float(temp1) < 100.0:
                        temp_a = "{:6.3f}".format(float(temp1))
                    else:
                        temp_a = "{:6.2f}".format(float(temp1))
                if temp2 != "":
                    if float(temp2) < 10.0:
                        temp_b = "{:6.4f}".format(float(temp2))
                    elif float(temp2) < 100.0:
                        temp_b = "{:6.3f}".format(float(temp2))
                    else:
                        temp_b = "{:6.2f}".format(float(temp2))
            elif isHe3TLTemp:
                temp_a_path = "runInfo/measRslt/devLog,devName:%s/devStatus/params/param/stsDM00512" % ("Shin-TL")
                temp_b_path = "runInfo/measRslt/devLog,devName:%s/devStatus/params/param/stsDM00509" % ("Shin-TL")
                # Read Temperature from run.xml
                temp1 = tt.PutContent(temp_a_path)
                temp2 = tt.PutContent(temp_b_path)
                if temp1 != "":
                    if float(temp1) < 10.0:
                        temp_a = "{:6.4f}".format(float(temp1))
                    elif float(temp1) < 100.0:
                        temp_a = "{:6.3f}".format(float(temp1))
                    else:
                        temp_a = "{:6.2f}".format(float(temp1))
                if temp2 != "":
                    if float(temp2) < 10.0:
                        temp_b = "{:6.4f}".format(float(temp2))
                    elif float(temp2) < 100.0:
                        temp_b = "{:6.3f}".format(float(temp2))
                    else:
                        temp_b = "{:6.2f}".format(float(temp2))
            elif isCRY3HETemp:
                temp_Sample_path = "runInfo/measRslt/devLog,devName:%s/devStatus/params/param/stsDM00509" % ("CRY3HE") # Sample
                temp_3HePot2_path = "runInfo/measRslt/devLog,devName:%s/devStatus/params/param/stsDM00515" % ("CRY3HE") # 3HePot2
                flag_temp_path = tt.PutContent("runInfo/measRslt/devLog,devName:%s/devStatus/params/param/stsDM04562" % ("CRY3HE"))

                # Read Temperature from run.xml
                temp1 = 0.0
                temp2 = 0.0
                if flag_temp_path == "3HePot2":
                    temp1 = float(tt.PutContent(temp_3HePot2_path))
                elif flag_temp_path == "Sample":
                    temp1 = float(tt.PutContent(temp_Sample_path))
                else:
                    temp1 = float(tt.PutContent(temp_Sample_path))
                    temp2 = float(tt.PutContent(temp_3HePot2_path))
                if float(temp1) < 10.0:
                    temp_a = "{:6.4f}".format(float(temp1))
                elif float(temp1) < 100.0:
                    temp_a = "{:6.3f}".format(float(temp1))
                else:
                    temp_a = "{:6.2f}".format(float(temp1))

                temp_b = "----"
                if temp2 != 0.0:
                    if float(temp2) < 10.0:
                        temp_b = "{:6.4f}".format(float(temp2))
                    elif float(temp2) < 100.0:
                        temp_b = "{:6.3f}".format(float(temp2))
                    else:
                        temp_b = "{:6.2f}".format(float(temp2))
            else:
                devname_temp_list = devname_temp.split(",")
                temp_path = "runInfo/measRslt/devLog,devName:%s/devStatus/params/param" % (
                    devname_temp_list[0])
                # print("## [inamura 190128] devname_temp_list=%s, %s, %s"%(tuple(devname_temp_list)))
                sensors_dic = {"A": "temperature_a", "B": "temperature_b", "C": "temperature_c",
                               "D1": "temperature_d1", "D2": "temperature_d2", "D3": "temperature_d3", "D4": "temperature_d4"}
                temp_sensors = [sensors_dic["A"], sensors_dic["B"]]
                temp_sensors_name = ["A", "B"]
                if len(devname_temp_list) > 1 and len(devname_temp_list) <= 3:
                    sensor_list = devname_temp_list[1:]
                    try:
                        for i, a_sensor in enumerate(sensor_list):
                            temp_sensors[i] = sensors_dic[a_sensor]
                            temp_sensors_name[i] = a_sensor
                    except KeyError:
                        raise UserWarning("Given sensers name is invalid.")
                Output[0] = Output[0].replace(
                    "T_A ", "T_%s " % (temp_sensors_name[0]))
                Output[0] = Output[0].replace(
                    "T_B ", "T_%s " % (temp_sensors_name[1]))
                temp_cnt = tt.PutContent(temp_path + "/temperature")
                if temp_cnt == "":
                    temp = "  --- "
                else:
                    temp = "%6.2f" % (float(temp_cnt))

                # read temperature A
                temp_a_cnt = tt.PutContent(temp_path + "/" + temp_sensors[0])
                if temp_a_cnt == "":
                    temp_a = "set_T="
                else:
                    temp_a = "%6.2f" % (float(temp_a_cnt))

                # read temperature B
                temp_b_cnt = tt.PutContent(temp_path + "/" + temp_sensors[1])
                if temp_b_cnt == "":
                    temp_b = temp
                else:
                    temp_b = "%6.2f" % (float(temp_b_cnt))

            # read angle of the gonio
            if is7TmagnetGonio:  # if dev is 7T magnet
                gonio_path = "runInfo/measRslt/devLog,devName:%s/devStatus/params/param/%s" % (
                    devname_gonio, paramname_7Tmagnet_gonio)
            elif isHe3TLGonio:
                gonio_path = "runInfo/measRslt/devLog,devName:%s/devStatus/params/param/rs_angle_pv" % ("Gonio-He3TL")
            else:
                gonio_path = "runInfo/measRslt/devLog,devName:%s/devStatus/params/param/th" % (
                    devname_gonio)
            gonio_cnt = tt.PutContent(gonio_path)
            if gonio_cnt == "":
                gonio = "    ---    "
            else:
                gonio = "%8.3f" % (float(gonio_cnt))

            del tt

            # get proton current
            (runNo, s_date, s_time, e_date, e_time, proton, kicker) = GetMeasBC(
                runno, flag_proton, offset_sec, isCT8Neutron)

            # store the output in the list
            cnt = ""
            if flag_proton == 0 or flag_proton == 1:
                cnt = "%6d   %s %s   %s %s     %s   %s %s   %s" % (
                    runno, s_date, s_time, e_date, e_time, proton, temp_a, temp_b, gonio)
            elif flag_proton == 2:
                cnt = "%6d   %s %s   %s %s     %s   %6s %6s   %8s" % (
                    runno, s_date, s_time, e_date, e_time, kicker, temp_a, temp_b, gonio)
            elif flag_proton == 3:
                cnt = "%6d   %s %s  %s %s      %s   %s   %6s %6s %8s" % (
                    runno, s_date, s_time, e_date, e_time, kicker, proton, temp_a, temp_b, gonio)
            elif flag_proton == 4:
                cnt = "%6d   %s %s  %s %s %s %s   %6s  %6s  %8s" % (
                    runno, s_date, s_time, e_date, e_time, kicker, proton, temp_a, temp_b, gonio)

            Output.append(cnt)

        run_no += 1
        if run_no > fin_no:
            break

    print()  # print blank line
    print("---------------------------------------------------------------------------------------------------------------------------------")
    for out in Output:  # print the output
        print(out)
    print("---------------------------------------------------------------------------------------------------------------------------------")

    # save as text file
    if output_name != "":
        print("     Output file={}".format(output_name))
        fo = open(output_name, "w")
        for out in Output:
            fo.write(out + "\n")
        fo.close()

#########################################


if __name__ == '__main__':
    MakeRunList(sys.argv)



# -*- coding: utf-8 -*-
#
# $Date: 2012-08-22 18:06:43 +0900 (水, 22 8 2012) $
# $Rev: 32 $
#
import math

MILLI = 1.0e-3
MICRO = 1.0e-6
NEUTRON_MASS = 1.67492728e-27 #[kg]
ELECTRON_VOLT = 1.60217653e-19 #[J]
MILLI_ELECTRON_VOLT = ELECTRON_VOLT * MILLI
PLANCK_CONST = 6.62606896e-34 # [J*s]
DIRAC_CONST = PLANCK_CONST / 2.0 / math.pi
ANGSTROM = 1.0e-10
ENG_FAC = DIRAC_CONST ** 2 / (2.0 * NEUTRON_MASS) / ANGSTROM ** 2
MEV_ENG_FAC = ENG_FAC / MILLI_ELECTRON_VOLT

# GEOMETRICAL PARAMETERS
GEOM_TINY_VALUE = 1.0e-12

# SCALAR FIELD LIST
ENERGY_TRANSFER = "Energy transfer [meV]"
DETECT_INTENSITY = "Detect intensity"
PIXEL = "Pixel No."

# Q POINT VALUE LIST
QPVAL_ET = ENERGY_TRANSFER
QPVAL_PXNO = PIXEL
QPVAL_PSDID = "PSD"
QPVAL_INSIDE = "is_inside"



#!/usr/bin/python
import Manyo as m
API = m.AcquireNeutronSourceTextInformation()
##################################################
def txtInfo4(sig,begin,end,step):
    firstTxt=[]
    secondTxt=[]
    print "txtInfo-4 >>>",sig,begin,end,step

    API.GetTextInformation(sig,begin,end,step)
    firstTxt = API.PutTextFirstInformation()
    secondTxt = API.PutTextSecondInformation() 

    return firstTxt,secondTxt
##################################################
def txtInfo2(sig,begin):
    firstTxt=[]
    secondTxt=[]
    print "txtInfo-2 >>>",sig,begin

    API.GetTextInformation(sig,begin)
    firstTxt = API.PutTextFirstInformation()
    secondTxt = API.PutTextSecondInformation() 

    return firstTxt,secondTxt
##################################################
def txtInfo1(sig):
    firstTxt=[]
    secondTxt=[]
    print "txtInfo-1 >>>",sig

    API.GetTextInformation(sig)
    firstTxt = API.PutTextFirstInformation()
    secondTxt = API.PutTextSecondInformation() 

    return firstTxt,secondTxt
##################################################

#firstStr, secondStr = txtInfo4("BS","2009/06/03 00:10:00","2009/06/03 03:00:00",1)
#firstStr, secondStr = txtInfo4("BS","2009/06/03 00:00:00","2009/06/03 10:00:00",0)
firstStr, secondStr = txtInfo2("BS","2009/06/03 00:00:00")
#firstStr, secondStr = txtInfo2("BS","")
#firstStr, secondStr = txtInfo1("BS")

print
print "      ##### result #####"
for i in range(len(firstStr)):
    print "[",i,"] =", firstStr[i],"<--->", secondStr[i]
print



import Manyo.Utsusemi as mu

tt=mu.UtsusemiDetectorEfficiencyCorrection()
tt.Initialize( 99999, "AMR-SUS304-3He-PSD" )
tt.MakeApproximateData( "AMR-SUS304-3He-PSD.dat", 0.1, 1000, 1000, -50.0, 50.0, 1000 )
del tt



# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'SequencerQ_Main.ui'
##
## Created by: Qt User Interface Compiler version 6.8.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QDate, QDateTime, QLocale,
    QMetaObject, QObject, QPoint, QRect,
    QSize, QTime, QUrl, Qt)
from PySide6.QtGui import (QAction, QBrush, QColor, QConicalGradient,
    QCursor, QFont, QFontDatabase, QGradient,
    QIcon, QImage, QKeySequence, QLinearGradient,
    QPainter, QPalette, QPixmap, QRadialGradient,
    QTransform)
from PySide6.QtWidgets import (QApplication, QFrame, QGroupBox, QHeaderView,
    QLabel, QLineEdit, QMainWindow, QPushButton,
    QSizePolicy, QStatusBar, QTextBrowser, QTreeWidget,
    QTreeWidgetItem, QWidget)

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        if not MainWindow.objectName():
            MainWindow.setObjectName(u"MainWindow")
        MainWindow.resize(1174, 727)
        MainWindow.setUnifiedTitleAndToolBarOnMac(False)
        self.actionFile = QAction(MainWindow)
        self.actionFile.setObjectName(u"actionFile")
        self.centralwidget = QWidget(MainWindow)
        self.centralwidget.setObjectName(u"centralwidget")
        self.SplashPanel = QLabel(self.centralwidget)
        self.SplashPanel.setObjectName(u"SplashPanel")
        self.SplashPanel.setGeometry(QRect(10, 10, 335, 50))
        self.groupBox = QGroupBox(self.centralwidget)
        self.groupBox.setObjectName(u"groupBox")
        self.groupBox.setGeometry(QRect(370, 10, 261, 61))
        self.btClear = QPushButton(self.groupBox)
        self.btClear.setObjectName(u"btClear")
        self.btClear.setGeometry(QRect(10, 25, 51, 32))
        self.btOpen = QPushButton(self.groupBox)
        self.btOpen.setObjectName(u"btOpen")
        self.btOpen.setGeometry(QRect(80, 25, 32, 32))
        self.btSaveas = QPushButton(self.groupBox)
        self.btSaveas.setObjectName(u"btSaveas")
        self.btSaveas.setGeometry(QRect(120, 25, 32, 32))
        self.btCCD = QPushButton(self.groupBox)
        self.btCCD.setObjectName(u"btCCD")
        self.btCCD.setGeometry(QRect(160, 25, 99, 32))
        self.groupBox_2 = QGroupBox(self.centralwidget)
        self.groupBox_2.setObjectName(u"groupBox_2")
        self.groupBox_2.setGeometry(QRect(650, 10, 511, 61))
        self.btBegin = QPushButton(self.groupBox_2)
        self.btBegin.setObjectName(u"btBegin")
        self.btBegin.setGeometry(QRect(20, 25, 80, 32))
        self.btStop = QPushButton(self.groupBox_2)
        self.btStop.setObjectName(u"btStop")
        self.btStop.setGeometry(QRect(110, 25, 80, 32))
        self.btResume = QPushButton(self.groupBox_2)
        self.btResume.setObjectName(u"btResume")
        self.btResume.setGeometry(QRect(230, 25, 150, 32))
        self.btVis = QPushButton(self.groupBox_2)
        self.btVis.setObjectName(u"btVis")
        self.btVis.setGeometry(QRect(410, 25, 100, 32))
        self.line = QFrame(self.groupBox_2)
        self.line.setObjectName(u"line")
        self.line.setGeometry(QRect(390, 25, 20, 31))
        self.line.setFrameShape(QFrame.Shape.VLine)
        self.line.setFrameShadow(QFrame.Shadow.Sunken)
        self.tree0 = QTreeWidget(self.centralwidget)
        __qtreewidgetitem = QTreeWidgetItem()
        __qtreewidgetitem.setText(0, u"1");
        self.tree0.setHeaderItem(__qtreewidgetitem)
        self.tree0.setObjectName(u"tree0")
        self.tree0.setGeometry(QRect(20, 70, 300, 320))
        self.tree0.setHeaderHidden(True)
        self.list1 = QTreeWidget(self.centralwidget)
        __qtreewidgetitem1 = QTreeWidgetItem()
        __qtreewidgetitem1.setText(0, u"1");
        self.list1.setHeaderItem(__qtreewidgetitem1)
        self.list1.setObjectName(u"list1")
        self.list1.setGeometry(QRect(370, 110, 800, 280))
        self.st0 = QLabel(self.centralwidget)
        self.st0.setObjectName(u"st0")
        self.st0.setGeometry(QRect(380, 70, 91, 17))
        self.btAdd = QPushButton(self.centralwidget)
        self.btAdd.setObjectName(u"btAdd")
        self.btAdd.setGeometry(QRect(330, 100, 32, 32))
        self.btRemove = QPushButton(self.centralwidget)
        self.btRemove.setObjectName(u"btRemove")
        self.btRemove.setGeometry(QRect(330, 150, 32, 32))
        self.btCopyAdd = QPushButton(self.centralwidget)
        self.btCopyAdd.setObjectName(u"btCopyAdd")
        self.btCopyAdd.setGeometry(QRect(330, 220, 32, 32))
        self.btUp = QPushButton(self.centralwidget)
        self.btUp.setObjectName(u"btUp")
        self.btUp.setGeometry(QRect(330, 270, 32, 32))
        self.btDown = QPushButton(self.centralwidget)
        self.btDown.setObjectName(u"btDown")
        self.btDown.setGeometry(QRect(330, 320, 32, 32))
        self.stCurrentDir = QLabel(self.centralwidget)
        self.stCurrentDir.setObjectName(u"stCurrentDir")
        self.stCurrentDir.setGeometry(QRect(470, 70, 671, 17))
        self.st1 = QLabel(self.centralwidget)
        self.st1.setObjectName(u"st1")
        self.st1.setGeometry(QRect(710, 90, 68, 17))
        self.status = QLabel(self.centralwidget)
        self.status.setObjectName(u"status")
        self.status.setGeometry(QRect(780, 90, 161, 17))
        self.groupBox_3 = QGroupBox(self.centralwidget)
        self.groupBox_3.setObjectName(u"groupBox_3")
        self.groupBox_3.setGeometry(QRect(380, 390, 781, 311))
        self.st2 = QLabel(self.groupBox_3)
        self.st2.setObjectName(u"st2")
        self.st2.setGeometry(QRect(140, 30, 101, 17))
        self.retval = QLineEdit(self.groupBox_3)
        self.retval.setObjectName(u"retval")
        self.retval.setGeometry(QRect(240, 25, 150, 30))
        self.btSet = QPushButton(self.groupBox_3)
        self.btSet.setObjectName(u"btSet")
        self.btSet.setGeometry(QRect(590, 25, 120, 30))
        self.line_2 = QFrame(self.groupBox_3)
        self.line_2.setObjectName(u"line_2")
        self.line_2.setGeometry(QRect(10, 50, 761, 16))
        self.line_2.setFrameShape(QFrame.Shape.HLine)
        self.line_2.setFrameShadow(QFrame.Shadow.Sunken)
        self.arg1 = QLineEdit(self.groupBox_3)
        self.arg1.setObjectName(u"arg1")
        self.arg1.setGeometry(QRect(10, 80, 240, 24))
        self.arg2 = QLineEdit(self.groupBox_3)
        self.arg2.setObjectName(u"arg2")
        self.arg2.setGeometry(QRect(270, 80, 240, 24))
        self.arg3 = QLineEdit(self.groupBox_3)
        self.arg3.setObjectName(u"arg3")
        self.arg3.setGeometry(QRect(530, 80, 240, 24))
        self.arg4 = QLineEdit(self.groupBox_3)
        self.arg4.setObjectName(u"arg4")
        self.arg4.setGeometry(QRect(10, 130, 240, 24))
        self.arg5 = QLineEdit(self.groupBox_3)
        self.arg5.setObjectName(u"arg5")
        self.arg5.setGeometry(QRect(270, 130, 240, 24))
        self.arg6 = QLineEdit(self.groupBox_3)
        self.arg6.setObjectName(u"arg6")
        self.arg6.setGeometry(QRect(530, 130, 240, 24))
        self.arg7 = QLineEdit(self.groupBox_3)
        self.arg7.setObjectName(u"arg7")
        self.arg7.setGeometry(QRect(10, 180, 240, 24))
        self.arg8 = QLineEdit(self.groupBox_3)
        self.arg8.setObjectName(u"arg8")
        self.arg8.setGeometry(QRect(270, 180, 240, 24))
        self.arg9 = QLineEdit(self.groupBox_3)
        self.arg9.setObjectName(u"arg9")
        self.arg9.setGeometry(QRect(530, 180, 240, 24))
        self.arg10 = QLineEdit(self.groupBox_3)
        self.arg10.setObjectName(u"arg10")
        self.arg10.setGeometry(QRect(10, 230, 240, 24))
        self.arg11 = QLineEdit(self.groupBox_3)
        self.arg11.setObjectName(u"arg11")
        self.arg11.setGeometry(QRect(270, 230, 240, 24))
        self.arg12 = QLineEdit(self.groupBox_3)
        self.arg12.setObjectName(u"arg12")
        self.arg12.setGeometry(QRect(530, 230, 240, 24))
        self.arg13 = QLineEdit(self.groupBox_3)
        self.arg13.setObjectName(u"arg13")
        self.arg13.setGeometry(QRect(10, 280, 240, 24))
        self.arg14 = QLineEdit(self.groupBox_3)
        self.arg14.setObjectName(u"arg14")
        self.arg14.setGeometry(QRect(270, 280, 240, 24))
        self.arg15 = QLineEdit(self.groupBox_3)
        self.arg15.setObjectName(u"arg15")
        self.arg15.setGeometry(QRect(530, 280, 240, 24))
        self.argst1 = QLabel(self.groupBox_3)
        self.argst1.setObjectName(u"argst1")
        self.argst1.setGeometry(QRect(20, 60, 231, 17))
        self.argst2 = QLabel(self.groupBox_3)
        self.argst2.setObjectName(u"argst2")
        self.argst2.setGeometry(QRect(280, 60, 231, 17))
        self.argst3 = QLabel(self.groupBox_3)
        self.argst3.setObjectName(u"argst3")
        self.argst3.setGeometry(QRect(540, 60, 231, 17))
        self.argst4 = QLabel(self.groupBox_3)
        self.argst4.setObjectName(u"argst4")
        self.argst4.setGeometry(QRect(20, 110, 231, 17))
        self.argst5 = QLabel(self.groupBox_3)
        self.argst5.setObjectName(u"argst5")
        self.argst5.setGeometry(QRect(280, 110, 231, 17))
        self.argst6 = QLabel(self.groupBox_3)
        self.argst6.setObjectName(u"argst6")
        self.argst6.setGeometry(QRect(540, 110, 231, 17))
        self.argst7 = QLabel(self.groupBox_3)
        self.argst7.setObjectName(u"argst7")
        self.argst7.setGeometry(QRect(20, 160, 231, 17))
        self.argst8 = QLabel(self.groupBox_3)
        self.argst8.setObjectName(u"argst8")
        self.argst8.setGeometry(QRect(280, 160, 231, 17))
        self.argst9 = QLabel(self.groupBox_3)
        self.argst9.setObjectName(u"argst9")
        self.argst9.setGeometry(QRect(540, 160, 231, 17))
        self.argst10 = QLabel(self.groupBox_3)
        self.argst10.setObjectName(u"argst10")
        self.argst10.setGeometry(QRect(20, 210, 231, 17))
        self.argst11 = QLabel(self.groupBox_3)
        self.argst11.setObjectName(u"argst11")
        self.argst11.setGeometry(QRect(280, 210, 231, 17))
        self.argst12 = QLabel(self.groupBox_3)
        self.argst12.setObjectName(u"argst12")
        self.argst12.setGeometry(QRect(540, 210, 231, 17))
        self.argst13 = QLabel(self.groupBox_3)
        self.argst13.setObjectName(u"argst13")
        self.argst13.setGeometry(QRect(20, 260, 231, 17))
        self.argst14 = QLabel(self.groupBox_3)
        self.argst14.setObjectName(u"argst14")
        self.argst14.setGeometry(QRect(280, 260, 231, 17))
        self.argst15 = QLabel(self.groupBox_3)
        self.argst15.setObjectName(u"argst15")
        self.argst15.setGeometry(QRect(540, 260, 231, 17))
        self.funcdoc = QTextBrowser(self.centralwidget)
        self.funcdoc.setObjectName(u"funcdoc")
        self.funcdoc.setGeometry(QRect(20, 400, 330, 280))
        MainWindow.setCentralWidget(self.centralwidget)
        self.statusbar = QStatusBar(MainWindow)
        self.statusbar.setObjectName(u"statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)

        QMetaObject.connectSlotsByName(MainWindow)
    # setupUi

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QCoreApplication.translate("MainWindow", u"MainWindow", None))
        self.actionFile.setText(QCoreApplication.translate("MainWindow", u"File", None))
        self.SplashPanel.setText("")
        self.groupBox.setTitle(QCoreApplication.translate("MainWindow", u"File", None))
        self.btClear.setText(QCoreApplication.translate("MainWindow", u"Clear", None))
        self.btOpen.setText("")
        self.btSaveas.setText("")
        self.btCCD.setText(QCoreApplication.translate("MainWindow", u"Current Dir", None))
        self.groupBox_2.setTitle(QCoreApplication.translate("MainWindow", u"Control", None))
        self.btBegin.setText(QCoreApplication.translate("MainWindow", u"Start", None))
        self.btStop.setText(QCoreApplication.translate("MainWindow", u"Stop", None))
        self.btResume.setText(QCoreApplication.translate("MainWindow", u"Resume", None))
        self.btVis.setText(QCoreApplication.translate("MainWindow", u"Visualize", None))
        self.st0.setText(QCoreApplication.translate("MainWindow", u"Current Dir :", None))
        self.btAdd.setText("")
        self.btRemove.setText("")
        self.btCopyAdd.setText("")
        self.btUp.setText("")
        self.btDown.setText("")
        self.stCurrentDir.setText("")
        self.st1.setText(QCoreApplication.translate("MainWindow", u"Status :", None))
        self.status.setText(QCoreApplication.translate("MainWindow", u"Executable", None))
        self.groupBox_3.setTitle("")
        self.st2.setText(QCoreApplication.translate("MainWindow", u"Return Label :", None))
        self.btSet.setText(QCoreApplication.translate("MainWindow", u"Set", None))
        self.argst1.setText(QCoreApplication.translate("MainWindow", u"Argument1", None))
        self.argst2.setText(QCoreApplication.translate("MainWindow", u"Argument2", None))
        self.argst3.setText(QCoreApplication.translate("MainWindow", u"Argument3", None))
        self.argst4.setText(QCoreApplication.translate("MainWindow", u"Argument4", None))
        self.argst5.setText(QCoreApplication.translate("MainWindow", u"Argument5", None))
        self.argst6.setText(QCoreApplication.translate("MainWindow", u"Argument6", None))
        self.argst7.setText(QCoreApplication.translate("MainWindow", u"Argument7", None))
        self.argst8.setText(QCoreApplication.translate("MainWindow", u"Argument8", None))
        self.argst9.setText(QCoreApplication.translate("MainWindow", u"Argument9", None))
        self.argst10.setText(QCoreApplication.translate("MainWindow", u"Argument10", None))
        self.argst11.setText(QCoreApplication.translate("MainWindow", u"Argument11", None))
        self.argst12.setText(QCoreApplication.translate("MainWindow", u"Argument12", None))
        self.argst13.setText(QCoreApplication.translate("MainWindow", u"Argument13", None))
        self.argst14.setText(QCoreApplication.translate("MainWindow", u"Argument14", None))
        self.argst15.setText(QCoreApplication.translate("MainWindow", u"Argument15", None))
    # retranslateUi


################################################################################
## Form generated from reading UI file 'SequencerQ_Save.ui'
##
## Created by: Qt User Interface Compiler version 6.8.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QDate, QDateTime, QLocale,
    QMetaObject, QObject, QPoint, QRect,
    QSize, QTime, QUrl, Qt)
from PySide6.QtGui import (QBrush, QColor, QConicalGradient, QCursor,
    QFont, QFontDatabase, QGradient, QIcon,
    QImage, QKeySequence, QLinearGradient, QPainter,
    QPalette, QPixmap, QRadialGradient, QTransform)
from PySide6.QtWidgets import (QApplication, QDialog, QLabel, QPushButton,
    QSizePolicy, QTextEdit, QWidget)

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        if not Dialog.objectName():
            Dialog.setObjectName(u"Dialog")
        Dialog.resize(342, 170)
        self.comment = QTextEdit(Dialog)
        self.comment.setObjectName(u"comment")
        self.comment.setGeometry(QRect(10, 40, 320, 80))
        self.label = QLabel(Dialog)
        self.label.setObjectName(u"label")
        self.label.setGeometry(QRect(10, 10, 261, 17))
        self.btOk = QPushButton(Dialog)
        self.btOk.setObjectName(u"btOk")
        self.btOk.setGeometry(QRect(50, 130, 100, 32))
        self.btCancel = QPushButton(Dialog)
        self.btCancel.setObjectName(u"btCancel")
        self.btCancel.setGeometry(QRect(180, 130, 100, 32))

        self.retranslateUi(Dialog)

        QMetaObject.connectSlotsByName(Dialog)
    # setupUi

    def retranslateUi(self, Dialog):
        Dialog.setWindowTitle(QCoreApplication.translate("Dialog", u"Dialog", None))
        self.label.setText(QCoreApplication.translate("Dialog", u"Comments for the sequence :", None))
        self.btOk.setText(QCoreApplication.translate("Dialog", u"OK", None))
        self.btCancel.setText(QCoreApplication.translate("Dialog", u"Cancel", None))
    # retranslateUi


################################################################################
## Form generated from reading UI file 'SequencerQ_Vis.ui'
##
## Created by: Qt User Interface Compiler version 6.8.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QDate, QDateTime, QLocale,
    QMetaObject, QObject, QPoint, QRect,
    QSize, QTime, QUrl, Qt)
from PySide6.QtGui import (QBrush, QColor, QConicalGradient, QCursor,
    QFont, QFontDatabase, QGradient, QIcon,
    QImage, QKeySequence, QLinearGradient, QPainter,
    QPalette, QPixmap, QRadialGradient, QTransform)
from PySide6.QtWidgets import (QApplication, QComboBox, QGroupBox, QHeaderView,
    QLabel, QLineEdit, QMainWindow, QMenuBar,
    QPushButton, QSizePolicy, QStatusBar, QTreeWidget,
    QTreeWidgetItem, QWidget)

class Ui_visframe(object):
    def setupUi(self, visframe):
        if not visframe.objectName():
            visframe.setObjectName(u"visframe")
        visframe.resize(737, 340)
        self.centralwidget = QWidget(visframe)
        self.centralwidget.setObjectName(u"centralwidget")
        self.tree = QTreeWidget(self.centralwidget)
        __qtreewidgetitem = QTreeWidgetItem()
        __qtreewidgetitem.setText(0, u"1");
        self.tree.setHeaderItem(__qtreewidgetitem)
        self.tree.setObjectName(u"tree")
        self.tree.setGeometry(QRect(10, 10, 200, 265))
        self.tree.setHeaderHidden(True)
        self.groupBox = QGroupBox(self.centralwidget)
        self.groupBox.setObjectName(u"groupBox")
        self.groupBox.setGeometry(QRect(220, 10, 391, 281))
        self.arg1 = QLineEdit(self.groupBox)
        self.arg1.setObjectName(u"arg1")
        self.arg1.setGeometry(QRect(280, 30, 100, 28))
        self.arg2 = QLineEdit(self.groupBox)
        self.arg2.setObjectName(u"arg2")
        self.arg2.setGeometry(QRect(280, 60, 100, 28))
        self.arg3 = QLineEdit(self.groupBox)
        self.arg3.setObjectName(u"arg3")
        self.arg3.setGeometry(QRect(280, 90, 100, 28))
        self.arg4 = QLineEdit(self.groupBox)
        self.arg4.setObjectName(u"arg4")
        self.arg4.setGeometry(QRect(280, 120, 100, 28))
        self.arg5 = QLineEdit(self.groupBox)
        self.arg5.setObjectName(u"arg5")
        self.arg5.setGeometry(QRect(280, 150, 100, 28))
        self.arg6 = QLineEdit(self.groupBox)
        self.arg6.setObjectName(u"arg6")
        self.arg6.setGeometry(QRect(280, 180, 100, 28))
        self.arg7 = QLineEdit(self.groupBox)
        self.arg7.setObjectName(u"arg7")
        self.arg7.setGeometry(QRect(280, 210, 100, 28))
        self.arg8 = QLineEdit(self.groupBox)
        self.arg8.setObjectName(u"arg8")
        self.arg8.setGeometry(QRect(280, 240, 100, 28))
        self.argst1 = QLabel(self.groupBox)
        self.argst1.setObjectName(u"argst1")
        self.argst1.setGeometry(QRect(10, 30, 101, 20))
        self.argst2 = QLabel(self.groupBox)
        self.argst2.setObjectName(u"argst2")
        self.argst2.setGeometry(QRect(10, 60, 101, 20))
        self.argst3 = QLabel(self.groupBox)
        self.argst3.setObjectName(u"argst3")
        self.argst3.setGeometry(QRect(10, 90, 101, 20))
        self.argst4 = QLabel(self.groupBox)
        self.argst4.setObjectName(u"argst4")
        self.argst4.setGeometry(QRect(10, 120, 101, 20))
        self.argst5 = QLabel(self.groupBox)
        self.argst5.setObjectName(u"argst5")
        self.argst5.setGeometry(QRect(10, 150, 101, 20))
        self.argst6 = QLabel(self.groupBox)
        self.argst6.setObjectName(u"argst6")
        self.argst6.setGeometry(QRect(10, 180, 101, 20))
        self.argst7 = QLabel(self.groupBox)
        self.argst7.setObjectName(u"argst7")
        self.argst7.setGeometry(QRect(10, 210, 101, 20))
        self.argst8 = QLabel(self.groupBox)
        self.argst8.setObjectName(u"argst8")
        self.argst8.setGeometry(QRect(10, 240, 101, 20))
        self.argsc1 = QComboBox(self.groupBox)
        self.argsc1.setObjectName(u"argsc1")
        self.argsc1.setGeometry(QRect(110, 30, 161, 27))
        self.argsc2 = QComboBox(self.groupBox)
        self.argsc2.setObjectName(u"argsc2")
        self.argsc2.setGeometry(QRect(110, 60, 161, 27))
        self.argsc3 = QComboBox(self.groupBox)
        self.argsc3.setObjectName(u"argsc3")
        self.argsc3.setGeometry(QRect(110, 90, 161, 27))
        self.argsc4 = QComboBox(self.groupBox)
        self.argsc4.setObjectName(u"argsc4")
        self.argsc4.setGeometry(QRect(110, 120, 161, 27))
        self.argsc5 = QComboBox(self.groupBox)
        self.argsc5.setObjectName(u"argsc5")
        self.argsc5.setGeometry(QRect(110, 150, 161, 27))
        self.argsc6 = QComboBox(self.groupBox)
        self.argsc6.setObjectName(u"argsc6")
        self.argsc6.setGeometry(QRect(110, 180, 161, 27))
        self.argsc7 = QComboBox(self.groupBox)
        self.argsc7.setObjectName(u"argsc7")
        self.argsc7.setGeometry(QRect(110, 210, 161, 27))
        self.argsc8 = QComboBox(self.groupBox)
        self.argsc8.setObjectName(u"argsc8")
        self.argsc8.setGeometry(QRect(110, 240, 161, 27))
        self.retval = QLineEdit(self.centralwidget)
        self.retval.setObjectName(u"retval")
        self.retval.setGeometry(QRect(620, 60, 100, 28))
        self.label = QLabel(self.centralwidget)
        self.label.setObjectName(u"label")
        self.label.setGeometry(QRect(620, 40, 91, 17))
        self.btExec = QPushButton(self.centralwidget)
        self.btExec.setObjectName(u"btExec")
        self.btExec.setGeometry(QRect(630, 110, 80, 32))
        self.btClose = QPushButton(self.centralwidget)
        self.btClose.setObjectName(u"btClose")
        self.btClose.setGeometry(QRect(640, 170, 80, 32))
        visframe.setCentralWidget(self.centralwidget)
        self.menubar = QMenuBar(visframe)
        self.menubar.setObjectName(u"menubar")
        self.menubar.setGeometry(QRect(0, 0, 737, 24))
        visframe.setMenuBar(self.menubar)
        self.statusbar = QStatusBar(visframe)
        self.statusbar.setObjectName(u"statusbar")
        visframe.setStatusBar(self.statusbar)

        self.retranslateUi(visframe)

        QMetaObject.connectSlotsByName(visframe)
    # setupUi

    def retranslateUi(self, visframe):
        visframe.setWindowTitle(QCoreApplication.translate("visframe", u"MainWindow", None))
        self.groupBox.setTitle(QCoreApplication.translate("visframe", u"Arguments", None))
        self.argst1.setText(QCoreApplication.translate("visframe", u"Argument", None))
        self.argst2.setText(QCoreApplication.translate("visframe", u"Argument", None))
        self.argst3.setText(QCoreApplication.translate("visframe", u"Argument", None))
        self.argst4.setText(QCoreApplication.translate("visframe", u"Argument", None))
        self.argst5.setText(QCoreApplication.translate("visframe", u"Argument", None))
        self.argst6.setText(QCoreApplication.translate("visframe", u"Argument", None))
        self.argst7.setText(QCoreApplication.translate("visframe", u"Argument", None))
        self.argst8.setText(QCoreApplication.translate("visframe", u"Argument", None))
        self.label.setText(QCoreApplication.translate("visframe", u"Return Label", None))
        self.btExec.setText(QCoreApplication.translate("visframe", u"Execute", None))
        self.btClose.setText(QCoreApplication.translate("visframe", u"Close", None))
    # retranslateUi




#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""Formatting docstring for ConvManyoDoxy2Swig results

   Output files of ConvManyoDoxy2Swig are the swig interface file (XXX.i).
   This script renames XXX.i to XXX.p and formatting XXX.p file to output as XXX.i.

"""

from __future__ import print_function
import os
import glob

def Formatting( in_file, out_file ):
    """Formatting docstrng of in_file to output to out_file
    
    Args:
        in_file (string): Input file ( XXX.p, copied output file from ConvManyoDoxy2Swig  )
        out_file (string): Output file ( XXX.i )

    """
    out_list = []
    funcs_dic = {}

    f = open(in_file,"r")
    while(True):
        a_line = f.readline()
        if a_line=="":
            break
        if a_line.find('%feature("docstring")')!=0:
            out_list.append( a_line+"\n" )
            continue
        else:
            ind = a_line.find(' "')
            key_c = a_line[:ind]
            v=key_c.split(" ")
            v2 = []
            for v1 in v:
                if v1!="":
                    v2.append(v1)
            Key = v2[1]
            bar = ""
            Method = a_line[(ind+2):]

            LoopOn = True
            ind2 = Method.find('";')
            if ind2<0:
                Bar = ""
                if len(Method.strip())!=0:
                    for i in range(len(Method)):
                        Bar += "="
                    #Conts = Bar+"\n"+Method+Bar+"\n"
                    Conts = Method+Bar+"\n"
                else:
                    Conts = Method + "\n"
            else:
                Conts = Method[:ind2]+"\n"
                LoopOn = False
            Indent_spc = "    "
            Indent_spc_add = ""
            while(LoopOn):
                a_line2 = f.readline()
                if a_line2=="":
                    break
                a_line2 = a_line2.strip()
                if a_line2=="":
                    continue
                if a_line2.find("----------")>=0:
                    continue
                
                if a_line2.find("Args:")>=0 or a_line2.find("Returns:")>=0:
                    ind2 = a_line2.find('";')
                    if ind2<0:
                        Conts += ("\n"+Indent_spc+a_line2+"\n")
                    else:
                        Conts += ("\n"+Indent_spc+a_line2[:ind2]+"\n")
                        break
                    Indent_spc_add = "    "
                    continue

                ind2 = a_line2.find('";')
                if ind2<0:
                    Conts += (Indent_spc+Indent_spc_add+a_line2+"\n")
                else:
                    Conts += (Indent_spc+Indent_spc_add+a_line2[:ind2]+"\n")
                    break

            if Key in funcs_dic.keys():
                funcs_dic[Key] += Indent_spc+"\n"
                funcs_dic[Key] += Conts
            else:
                funcs_dic[Key] = (Conts+"\n")
                out_list.append("UTSUSEMI_DICKEY:"+Key+"\n")

    f.close()

    fo = open(out_file,"w")
    for item in out_list:
        k = item.strip()
        if k=="":
            continue
        ind = k.find("UTSUSEMI_DICKEY")
        if ind==0:
            key = k.replace("UTSUSEMI_DICKEY:","")
            tmp = '%feature("docstring") '+key+' "'+funcs_dic[key]+'";\n'
            fo.write(tmp)
        else:
            fo.write(item)
    fo.close()

#####################################
if __name__ == '__main__':
    hh_list = glob.glob("interfaces/*.i")
    for a_file in hh_list:
        i_path=a_file
        p_path=a_file.replace(".i",".p")
        if os.path.exists( i_path ):
            os.system( "mv %s %s"%(i_path, p_path) )
            Formatting( p_path, i_path )
    



# -*- coding: utf-8 -*-
"""

"""
import vis.DetectMap as dpc
import time
import vis.MPlot as mp
import vis.M2Plot as mp2
import vis.VisualContM as vctm

# 予約語の定義
ret = None 
vp1 = None
vp2 = None
vc = None
vc2 = None
vc3 = None
ec = None
earray = None
DAT = None
ECM = None
vcm = None
        
###################################################                            
def DetectMapCommon(matrix=DAT):
        """
        Display Detector Map
        @param  matrix [Def:DAT]  ElementContainerMatrix Object 
        @retval None
        """ 
        dpc.MapFrame(None, matrix)    
        

###################################################                         
def MPlot(ec=ec):
        """
        Create 1D Plotter and Draw EC
        @param  ec [Def:EC]  ElementContainer
        @param  psd      PSD No.    
        @param  pixel    Pixel No.    
        @retval vp1    Instance of Plotter
        """ 
        # 親プロセス終了時に、プロッタを終了      
        return mp.MPlot(ec, True)
    
###################################################                            
def AddToMPlot(vp1=vp1, ec=ec):
        """
        Add EC to 1D Plotter
        @param  vp1 [Def:vp1]     Instance of 1D Plotter
        @param  ec  [Def:EC]      ElementContainer
        @retval None
        """ 
        vp1.AddData(ec)  
        
###################################################                         
def M2Plot(matrix=ECM):
        """
        Create 2D Plotter and display 2D Map
        @param  matrix [Def:ECM]  ElementContainerArray
        @retval vp2  Instance of 2D Plotter
        """ 
        # 親プロセス終了時に、プロッタを終了      
        return mp2.M2Plot(matrix, True)

###################################################
def ChangeMap(vp2=vp2, matrix=ECM):
        """
        Change 2D Map of M2Plot
	@param  vp2 [Def:vp2]     Instance of 2D Plotter
        @param  matrix [Def:EMC]  ElementContainerArray
        @retval None
        """ 
        # Map データの変更
        vp2.ChangeMap(matrix)	

           

# 関数名登録ディクショナリ
_functions = {"DetectMapCommon":DetectMapCommon,
              "MPlot":MPlot,
              "AddToMPlot":AddToMPlot,
              "M2Plot":M2Plot,
	      "ChangeMap":ChangeMap,
	      }
_functionsOrder = [
	"DetectMapCommon",
	"MPlot",
	"AddToMPlot",
	"M2Plot",
	"ChangeMap",
	]
         



#! /usr/bin/env python
# -*- coding:utf-8 -*-
import tkinter
import os

class App(tkinter.Frame):
    def __init__(self, master = None):
        tkinter.Frame.__init__(self, master)
        self.master.title("SQW Launch")

        self.errorstr = tkinter.StringVar()
        self.errorstr.set("SQW Reduction.")
        display = tkinter.Label(self, textvariable = self.errorstr,
                              font = ('Helvetica', '14', 'bold'))
        display.pack( side = tkinter.TOP)

        lf_frame = tkinter.LabelFrame( self, text="Resolution", padx=2)

        f = tkinter.Button(lf_frame, text = "High Resolution Mode", width=22, height=2, command = self.launch_high)
        f.pack( side=tkinter.TOP, padx=2, pady=4)
        f = tkinter.Button(lf_frame, text = "Low Resolution Mode",  width=22, height=2, command = self.launch_low)
        f.pack( side=tkinter.TOP, padx=2, pady=4)

        lf_frame.pack( side=tkinter.TOP, expand=1,pady=6, padx=6)

        button2 = tkinter.Button(self, text = "Exit", command = self.master.destroy)
        button2.pack(padx = 6, pady = 3, side = tkinter.RIGHT)
        self.pack()

    def launch_high(self):
        os.system('xterm -e "source /opt/mlfsoft/python-utsusemi/utsusemi/DNA/bashrc.py3.DNA; export FastChopperUse=True ; python3 ~/SQW/SQW.py " &')
        self.master.destroy()

    def launch_low(self):
        os.system('xterm -e "source /opt/mlfsoft/python-utsusemi/utsusemi/DNA/bashrc.py3.DNA; export FastChopperUse=False ; python3 ~/SQW/SQW.py " &')
        self.master.destroy()


if __name__ == "__main__":
    app = App()
    app.mainloop()



import Manyo as mm
import os
import shutil
import uGao.MPlot as mp
import utsusemi.DNA.ana.Reduction.DeConvolutionBase as DC

# special reserved word for commands history
HISTORY = None

# reserved words for return value in this.
DAT = None
ecs = None
EC = None
EC1 = None
EC2 = None
ret = None


################################################################################################################

def EditInitLorentzParam(NumOfLor = 2, omega = "", ene0 = "", val = ""):
    """
    @param NumOfLor      (int)
    @param omega      (string)
    @param ene0       (string)
    @param val        (string)
    @retval None
    """
    return DC.EditInitLorentzParam(NumOfLor, omega, ene0, val)

################################################################################################################

def MemDeconvolution(ecData=EC1, ecRes=EC2, memData = 1,NumOfLor = 2,Itteration = 10,MemThreshold = 1.0,savepath = "/usr/local/mlf/DNA/tmp/Mem/"):
    """
    @param ecData           (ElementContainer)
    @param ecRes            (ElementContainer)
    @param memData          (int)
    @param NumOfLor         (int)
    @param Itteration       (int)
    @param MemThreshold     (int)
    @param savepath         (string)
    @retval EC              (ElementContainer)
    """
    return DC.MemDeconvolution(ecData,ecRes,memData,NumOfLor,Itteration,MemThreshold,savepath)

################################################################################################################

def MemExecuteManual():
    """
    @retval None
    """
    return DC.MemExecuteManual()

################################################################################################################

def ReadECAndWriteText(ec,filename= "sTest"):
    """
    @param ec     (ElementContaienr)
    @param filename         (string)
    @retval None
    """
    return DC.ReadECAndWriteText(ec,filename)

################################################################################################################

def MemExecute(DataFileName = "sDET05",ResFileName = "sV_5",memData = 1,NumOfLor = 2,columnParam = "",Itteration = 10,MemThreshold = 1.0,savepath = "/usr/local/mlf/DNA/tmp/Mem/"):
    """
    @param DataFileName     (string)
    @param ResFileName      (string)
    @param memData          (int)
    @param NumOfLor         (int)
    @param columnParam      (string)
    @param Itteration       (int)
    @param MemThreshold     (int)
    @param savepath         (string)
    @retval None
    """
    return DC.MemExecute(DataFileName,ResFileName,memData,NumOfLor,columnParam,Itteration,MemThreshold,savepath)

################################################################################################################

def LoadFinalData(filename="outputSqe.txt",SaveDataPath = "/usr/local/mlf/DNA/tmp/Mem/",linenumber=6):
    """
    @param filename      (string)
    @param SaveDataPath  (string)
    @param linenumber       (int)
    @retval ec (ElementContainer)
    """
    return DC.LoadFinalData(filename,SaveDataPath,linenumber)

################################################################################################################

def LoadTextData(filename="TEMP6.DAT",SaveDataPath = "/usr/local/mlf/DNA/tmp/Mem/"):
    """
    @param filename      (string)
    @param SaveDataPath  (string)
    @retval ec (ElementContainer)
    """
    return DC.LoadTextData(filename,SaveDataPath)


################################################################################################################

def PrintFileNametype():
    """
    @retval None
    """
    return DC.PrintFileNametype()

################################################################################################################

def GslFFTDeconvolution(ecData=EC1, ecRes=EC2):
    """
    @param ecData           (ElementContainer)
    @param ecRes            (ElementContainer)
    @retval EC              (ElementContainer)
    """
    return DC.GslFFTDeconvolution(ecData, ecRes)

################################################################################################################

def GslFFTConvolution(ecData=EC1, ecRes=EC2):
    """
    @param ecData           (ElementContainer)
    @param ecRes            (ElementContainer)
    @retval EC              (ElementContainer)
    """
    return DC.GslFFTConvolution(ecData, ecRes)

################################################################################################################

def NumpyFFTDeconvolution(ecDet=EC1,ecRes=EC2):
    """
    @param ecDet            (ElementContainer)
    @param ecRes            (ElementContainer)
    @retval EC2           (ElementContainer)
    """
    return DC.NumpyFFTDeconvolution(ecDet,ecRes)

################################################################################################################


def NumpyFFTConvolution(ecDet=EC1,ecRes=EC2):
    """
    @param ecDet            (ElementContainer)
    @param ecRes            (ElementContainer)
    @retval EC2           (ElementContainer)
    """
    return DC.NumpyFFTConvolution(ecDet,ecRes)

################################################################################################################

def NumpyFFT(ec0=EC):
    """
    @param ec0            (ElementContainer)
    @retval EC2           (ElementContainer)
    """
    return DC.NumpyFFT(ec0)

################################################################################################################

def NumpyIFFT(ec0=EC):
    """
    @param ec0            (ElementContainer)
    @retval EC2           (ElementContainer)
    """
    return DC.NumpyIFFT(ec0)

################################################################################################################

def OutputPartOfEC(ec=EC,initial=0.0,final=0.1):
    """
    @param  ec         (ElementContaienr)
    @param  initial    (double)
    @param  final      (double)
    @retval EC         (ElementContainer)
    """
    return DC.OutputPartOfEC(ec,initial,final)

################################################################################################################

# Dictionary for entry the name of functions
_functions = {
              "MemDeconvolution":MemDeconvolution,
              "LoadFinalData":LoadFinalData,
              "ReadECAndWriteText":ReadECAndWriteText,
              "EditInitLorentzParam":EditInitLorentzParam,
              "MemExecute":MemExecute,
              "LoadTextData":LoadTextData,
              "PrintFileNametype":PrintFileNametype,
              "GslFFTConvolution":GslFFTConvolution,
              "GslFFTDeconvolution":GslFFTDeconvolution,
              "NumpyFFTConvolution":NumpyFFTConvolution,
              "NumpyFFTDeconvolution":NumpyFFTDeconvolution,
              "NumpyFFT":NumpyFFT,
              "NumpyIFFT":NumpyIFFT,
              "OutputPartOfEC":OutputPartOfEC
              }
